@@ -27,11 +27,9 @@
 #include <boost/scoped_ptr.hpp>
 #include "ScrollView.h"
 
-#if defined(NUX_OS_WINDOWS)
 #include "NuxGraphics/Events.h"
-#elif defined(NUX_OS_LINUX)
-#include "NuxGraphics/Events.h"
-#include "NuxGraphics/XInputWindow.h"
+#if defined(USE_X11)
+#  include "NuxGraphics/XInputWindow.h"
 #endif
 
 #include "InputArea.h"
@@ -79,7 +77,6 @@ namespace nux
     virtual Area* FindAreaUnderMouse(const Point& mouse_position, NuxEventType event_type);
     virtual void Draw(GraphicsEngine &graphics_engine, bool force_draw);
     virtual void DrawContent(GraphicsEngine &graphics_engine, bool force_draw);
-    virtual void PostDraw(GraphicsEngine &graphics_engine, bool force_draw);
 
     virtual Layout* GetLayout();
     virtual bool SetLayout(Layout *layout);
@@ -186,11 +183,18 @@ namespace nux
     //! Emit a signal when the BaseWindow becomes hidden.
     sigc::signal<void, BaseWindow*> sigHidden;
 
-    NString GetWindowName()
+    std::string GetWindowName()
     {
       return _name;
     }
 
+    void PresentInEmbeddedModeOnThisFrame(bool force = false);
+    void MarkPresentedInEmbeddedMode();
+    bool AllowPresentationInEmbeddedMode() const;
+    nux::Geometry const& LastPresentedGeometryInEmbeddedMode() const;
+
+    void PrepareParentRedirectedView();
+
 #ifdef NUX_GESTURES_SUPPORT
     virtual Area* GetInputAreaHitByGesture(const nux::GestureEvent &event);
 #endif
@@ -243,7 +247,7 @@ namespace nux
 
     bool ChildNeedsRedraw();
 
-    #if defined(NUX_OS_LINUX)
+    #if defined(USE_X11)
     bool m_input_window_enabled;
     XInputWindow *m_input_window;
     #endif
@@ -252,7 +256,7 @@ namespace nux
     //! Contains the background of the texture. Can be used to blur. It is set by the window compositor.
     ObjectPtr<BaseTexture> _background_texture;
 
-    NString _name;
+    std::string _name;
     bool _size_match_layout;
     bool _is_visible;
     bool _is_modal;
@@ -264,6 +268,14 @@ namespace nux
     bool _child_need_redraw;   //!<True is there is a child of the BaseWindow that needs to be redrawn;
     float _opacity;
 
+    bool _present_in_embedded_mode; //!<True if we should draw this window's
+                                    // backing texture to the screen on the
+                                    // next frame
+    nux::Geometry _last_presented_geometry_in_embedded_mode;
+
+    bool _contents_ready_for_presentation; //!<True if this window's contents has just been
+                                           // redrawn and it is awaiting presentation
+
     friend class PopUpWindow;
 
     friend class WindowThread;
