@@ -41,7 +41,6 @@ namespace nux
 
     virtual void Draw(GraphicsEngine &graphics_engine, bool force_draw);
     virtual void DrawContent(GraphicsEngine &graphics_engine, bool force_draw);
-    virtual void PostDraw(GraphicsEngine &graphics_engine, bool force_draw);
 
     virtual bool SetLayout(Layout *layout);
     void SetCaption(const char *Caption);
@@ -53,7 +52,6 @@ namespace nux
     virtual long PostLayoutManagement(long LayoutResult);
     virtual void ComputeContentPosition(float offsetX, float offsetY);
 
-    bool        bCaptionAvailable;
     BasicView   *m_CaptionArea;
     Layout     *m_layout;
 
