@@ -41,8 +41,7 @@ namespace nux
 
     virtual void Draw(GraphicsEngine &graphics_engine, bool force_draw);
   private:
-    virtual void DrawContent(GraphicsEngine &graphics_engine, bool force_draw) {};
-    virtual void PostDraw(GraphicsEngine &graphics_engine, bool force_draw) {};
+    virtual void DrawContent(GraphicsEngine & /* graphics_engine */, bool /* force_draw */) {};
 
     void HScrollBarHandler(void *v);
     void ScrollRight(void *v);
