@@ -45,7 +45,7 @@ namespace nux
   IntegerValidator::IntegerValidator(const IntegerValidator &copy)
   {
     m_Minimum   = copy.m_Minimum;
-    m_Minimum   = copy.m_Maximum;
+    m_Maximum   = copy.m_Maximum;
     _regexp_str    = copy._regexp_str;
     InitRegExp();
   }
@@ -55,7 +55,7 @@ namespace nux
     if (&rhs != this)
     {
       m_Minimum   = rhs.m_Minimum;
-      m_Minimum   = rhs.m_Maximum;
+      m_Maximum   = rhs.m_Maximum;
       _regexp_str    = rhs._regexp_str;
       InitRegExp();
     }
@@ -118,15 +118,13 @@ namespace nux
     return i;
   }
 
-  void IntegerValidator::Alternative(const char *str)
+  void IntegerValidator::Alternative(const char * /* str */)
   {
-    str = "0";
   }
 
-  NString IntegerValidator::ToString(int i)
+  std::string IntegerValidator::ToString(int i)
   {
-    NString Prec("%d");
-    return NString::Printf(Prec.GetTCharPtr(), i);
+    return std::to_string((long long)i);
   }
 
   int IntegerValidator::ToInteger(const char *str)
