@@ -9,13 +9,11 @@
 #include "FloatingWindow.h"
 
 #include "WindowThread.h"
+#include "MainLoopGLib.h"
 
 namespace nux
 {
-  namespace
-  {
-    logging::Logger logger("nux.windows.thread");
-  }
+  DECLARE_LOGGER(logger, "nux.windows.thread");
 
   #if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
 
@@ -45,6 +43,11 @@ namespace nux
     unsigned int id;
   } TimeoutData;
 
+  Event GetSystemEvent(WindowThread* window_thread)
+  {
+    return window_thread->GetNextEvent();
+  }
+
   gboolean nux_timeout_dispatch(gpointer user_data)
   {
     bool repeat = false;
@@ -52,7 +55,7 @@ namespace nux
     unsigned int return_code = 1;
 
     dd->window_thread->_inside_timer_loop = true;
-    repeat = GetTimer().ExecTimerHandler(dd->id)? true : false;
+    repeat = GetTimer().ExecTimerHandler(dd->id);
     dd->window_thread->_inside_timer_loop = false;
 
     if (dd->window_thread->IsEmbeddedWindow())
@@ -61,8 +64,7 @@ namespace nux
     }
     else
     {
-      Event event;
-      dd->window_thread->GetGraphicsDisplay().GetSystemEvent(&event);
+      Event event = GetSystemEvent(dd->window_thread);
       return_code = dd->window_thread->ProcessEvent(event);
     }
 
@@ -77,20 +79,24 @@ namespace nux
     return repeat;
   }
 
-  static gboolean nux_event_prepare(GSource *source, gint *timeout)
+  static gboolean nux_event_prepare(GSource * /* source */, gint *timeout)
   {
     nux_glib_threads_lock();
 
     gboolean retval;
     *timeout = -1;
-  #if defined(NUX_OS_WINDOWS)
+#if defined(NUX_OS_WINDOWS)
     MSG msg;
     retval = PeekMessageW(&msg, NULL, 0, 0, PM_NOREMOVE) ? TRUE : FALSE;
-  #elif defined(NUX_OS_LINUX)
+#elif defined(NUX_OS_LINUX)
+# if defined(USE_X11)
     retval = GetGraphicsDisplay()->HasXPendingEvent() ? TRUE : FALSE;
-  #else
-  #error Not implemented.
-  #endif
+# else
+    retval = false;
+# endif
+#else
+# error Not implemented.
+#endif
 
     nux_glib_threads_unlock();
     return retval;
@@ -100,36 +106,33 @@ namespace nux
   {
     nux_glib_threads_lock();
 
-    gboolean retval;
+    gboolean retval = FALSE;
     NuxEventSource *event_source = (NuxEventSource*) source;
 
     if ((event_source->event_poll_fd.revents & G_IO_IN))
     {
-  #if defined(NUX_OS_WINDOWS)
+#if defined(NUX_OS_WINDOWS)
       MSG msg;
       retval = PeekMessageW(&msg, NULL, 0, 0, PM_NOREMOVE) ? TRUE : FALSE;
-  #elif defined(NUX_OS_LINUX)
+#elif defined(NUX_OS_LINUX)
+#  if defined(USE_X11)
       retval = GetGraphicsDisplay()->HasXPendingEvent() ? TRUE : FALSE;
-  #else
-  #error Not implemented.
-  #endif
-    }
-    else
-    {
-      retval = FALSE;
+#  endif
+#else
+#  error Not implemented.
+#endif
     }
 
     nux_glib_threads_unlock();
     return retval;
   }
 
-  gboolean nux_event_dispatch(GSource *source, GSourceFunc  callback, gpointer user_data)
+  gboolean nux_event_dispatch(GSource * /* source */, GSourceFunc  /* callback */, gpointer user_data)
   {
     nux_glib_threads_lock();
     WindowThread *window_thread = NUX_STATIC_CAST(WindowThread *, user_data);
 
-    Event event;
-    window_thread->GetGraphicsDisplay().GetSystemEvent(&event);
+    Event event = GetSystemEvent(window_thread);
     unsigned int return_code = window_thread->ProcessEvent(event);
 
     if (return_code == 0 && !window_thread->IsEmbeddedWindow())
@@ -146,11 +149,13 @@ namespace nux
     nux_event_prepare,
     nux_event_check,
     nux_event_dispatch,
+    NULL,
+    NULL,
     NULL
   };
 
   // Timeline source functions
-  static gboolean nux_timeline_prepare (GSource  *source, gint *timeout)
+  static gboolean nux_timeline_prepare (GSource  * /* source */, gint *timeout)
   {
     // right now we are assuming that we are v-synced, so that will handle synchronizations
     // we could guess how long we have to wait for the next frame but thats rather ugly
@@ -160,21 +165,21 @@ namespace nux
     return TRUE;
   }
 
-  static gboolean nux_timeline_check(GSource  *source)
+  static gboolean nux_timeline_check(GSource  * /* source */)
   {
     return TRUE;
   }
 
-  static gboolean nux_timeline_dispatch(GSource *source, GSourceFunc callback, gpointer user_data)
+  static gboolean nux_timeline_dispatch(GSource *source, GSourceFunc /* callback */, gpointer user_data)
   {
-    GTimeVal time_val;
+#if !defined(NUX_MINIMAL)
     bool has_timelines_left = false;
     nux_glib_threads_lock();
-    g_source_get_current_time(source, &time_val);
+    gint64 micro_secs = g_source_get_time(source);
     WindowThread *window_thread = NUX_STATIC_CAST(WindowThread *, user_data);
 
     // pump the timelines
-    has_timelines_left = window_thread->ProcessTimelines(&time_val);
+    has_timelines_left = window_thread->ProcessTimelines(micro_secs);
 
     if (!has_timelines_left)
     {
@@ -184,6 +189,7 @@ namespace nux
     }
 
     nux_glib_threads_unlock();
+#endif
     return TRUE;
   }
 
@@ -192,6 +198,8 @@ namespace nux
     nux_timeline_prepare,
     nux_timeline_check,
     nux_timeline_dispatch,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -201,12 +209,15 @@ namespace nux
 
     if (!IsEmbeddedWindow())
     {
+
+#if GLIB_MAJOR_VERSION < 2 || GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 32
       static bool gthread_initialized = false;
 
       if (!gthread_initialized)
         g_thread_init(NULL);
 
       gthread_initialized = true;
+#endif
 
       if (((main_loop_glib_context_ == 0) || (main_loop_glib_ == 0)) && (main_context_created == false))
       {
@@ -245,9 +256,11 @@ namespace nux
 #if defined(NUX_OS_WINDOWS)
     event_source->event_poll_fd.fd = G_WIN32_MSG_HANDLE;
 #elif defined(NUX_OS_LINUX)
+#  if defined(USE_X11)
     event_source->event_poll_fd.fd = ConnectionNumber(GetGraphicsDisplay().GetX11Display());
+#  endif
 #else
-#error Not implemented.
+#  error Not implemented.
 #endif
 
     event_source->event_poll_fd.events = G_IO_IN;
@@ -275,8 +288,10 @@ namespace nux
         sigc::mem_fun(this, &WindowThread::ProcessGestureEvent));
 #endif
 
-    if (_Timelines->size() > 0)
+#if !defined(NUX_MINIMAL)
+    if (!_Timelines->empty())
       StartMasterClock();
+#endif
 
     if (!IsEmbeddedWindow())
     {
@@ -285,9 +300,104 @@ namespace nux
     }
   }
 
+  namespace
+  {
+    typedef struct _ExternalNuxSource
+    {
+      GSource source;
+      GPollFD pfd;
+    } ExternalNuxSource;
+
+    gboolean ExternalSourcePrepareFunc(GSource *source, gint *timeout)
+    {
+      /* Always block for new events */
+      *timeout = -1;
+      return FALSE;
+    }
+
+    gboolean ExternalSourceCheckFunc(GSource *source)
+    {
+      /* Only return true if there are events waiting for us */
+      ExternalNuxSource *extSource =
+          reinterpret_cast <ExternalNuxSource *>(source);
+      return extSource->pfd.revents == G_IO_IN;
+    }
+
+    gboolean ExternalSourceDispatchFunc(GSource     *source,
+                                        GSourceFunc callback,
+                                        gpointer    user_data)
+    {
+      return (*callback) (user_data);
+    }
+
+    static GSourceFuncs externalGLibFuncs =
+    {
+      &ExternalSourcePrepareFunc,
+      &ExternalSourceCheckFunc,
+      &ExternalSourceDispatchFunc, 
+      NULL,
+      /* Technically we shouldn't be touching these, but the compiler
+       * will complain if we don't */
+      0,
+      0
+    };
+  }
+
+  gboolean WindowThread::ExternalSourceCallback(gpointer user_data)
+  {
+    WindowThread::ExternalFdData *data =
+      reinterpret_cast <WindowThread::ExternalFdData *> (user_data);
+
+    data->cb ();
+    return TRUE;
+  }
+
+  void ExternalGLibSources::AddFdToGLibLoop(gint fd,
+                                            gpointer data,
+                                            GSourceFunc callback,
+                                            GMainContext *context)
+  {
+    GSource *source = g_source_new(&externalGLibFuncs, sizeof (ExternalNuxSource));
+    ExternalNuxSource *extSource =
+      reinterpret_cast <ExternalNuxSource *> (source);
+    extSource->pfd.fd = fd;
+    extSource->pfd.events = G_IO_IN;
+    extSource->pfd.revents = 0;
+
+    g_source_add_poll (source, &extSource->pfd);
+    g_source_set_callback (source, callback, data, NULL);
+
+    g_source_attach (source, context);
+  }
+
+  void ExternalGLibSources::RemoveFdFromGLibLoop(gpointer data)
+  {
+    g_source_remove_by_user_data(data);
+  }
+
+  void WindowThread::AddFdToGLibLoop(int fd,
+                                     gpointer data,
+                                     GSourceFunc callback)
+  {
+    external_glib_sources_->AddFdToGLibLoop(fd, data, callback, main_loop_glib_context_);
+  }
+
+  void WindowThread::RemoveFdFromGLibLoop(gpointer data)
+  {
+    external_glib_sources_->RemoveFdFromGLibLoop(data);
+  }
+
   void WindowThread::CleanupGlibLoop()
   {
     g_source_remove_by_funcs_user_data(&event_funcs, this);
+
+    for (std::list<ExternalFdData>::iterator it = _external_fds.begin();
+         it != _external_fds.end();
+         ++it)
+    {
+      gpointer data = reinterpret_cast<gpointer>(&(*it));
+      external_glib_sources_->RemoveFdFromGLibLoop(data);
+    }
   }
 
   unsigned int WindowThread::AddGLibTimeout(unsigned int duration)
@@ -326,7 +436,11 @@ namespace nux
     }
   }
 
+#if defined(NUX_OS_WINDOWS)
   bool WindowThread::AddChildWindowGlibLoop(WindowThread* wnd_thread)
+#else
+  bool WindowThread::AddChildWindowGlibLoop(WindowThread* /* wnd_thread */)
+#endif
   {
 #if defined(NUX_OS_WINDOWS)
     if (wnd_thread == NULL)
@@ -367,7 +481,6 @@ namespace nux
 
     if (_MasterClock == NULL)
     {
-      GTimeVal time_val;
       // make a source for our master clock
       _MasterClock = g_source_new(&timeline_funcs, sizeof(GSource));
 
@@ -380,10 +493,11 @@ namespace nux
       else if (main_loop_glib_context_ != 0)
         g_source_attach(_MasterClock, main_loop_glib_context_);
 
-
-      g_get_current_time(&time_val);
-      last_timeline_frame_time_sec_ = time_val.tv_sec;
-      last_timeline_frame_time_usec_ = time_val.tv_usec;
+#if !defined(NUX_MINIMAL)
+      gint64 micro_secs = g_source_get_time(_MasterClock);
+      last_timeline_frame_time_sec_ = micro_secs / 1000000;
+      last_timeline_frame_time_usec_ = micro_secs % 1000000;
+#endif
     }
   }
 
