@@ -87,7 +87,7 @@ namespace nux
     m_MenuBarItemList.clear();
   }
 
-  void MenuBar::Draw(GraphicsEngine &graphics_engine, bool force_draw)
+  void MenuBar::Draw(GraphicsEngine &graphics_engine, bool /* force_draw */)
   {
     Geometry base = GetGeometry();
     graphics_engine.PushClippingRectangle(base);
@@ -127,7 +127,7 @@ namespace nux
         }
         else
         {
-          GetPainter().PaintTextLineStatic(graphics_engine, GetFont(), item_geometry, area->GetBaseString().GetTCharPtr(), GetTextColor(), true, eAlignTextCenter);
+          GetPainter().PaintTextLineStatic(graphics_engine, GetFont(), item_geometry, area->GetBaseString(), GetTextColor(), true, eAlignTextCenter);
         }
       }
       else
@@ -144,7 +144,7 @@ namespace nux
         }
         else
         {
-          GetPainter().PaintTextLineStatic(graphics_engine, GetFont(), item_geometry, area->GetBaseString().GetTCharPtr(), GetTextColor(), true, eAlignTextCenter);
+          GetPainter().PaintTextLineStatic(graphics_engine, GetFont(), item_geometry, area->GetBaseString(), GetTextColor(), true, eAlignTextCenter);
         }
       }
     }
@@ -167,24 +167,19 @@ namespace nux
       }
       else
       {
-        GetPainter().PaintTextLineStatic(graphics_engine, GetFont(), item_geometry, area->GetBaseString().GetTCharPtr(), GetTextColor(), true, eAlignTextCenter);
+        GetPainter().PaintTextLineStatic(graphics_engine, GetFont(), item_geometry, area->GetBaseString(), GetTextColor(), true, eAlignTextCenter);
       }
     }
 
     graphics_engine.PopClippingRectangle();
   }
 
-  void MenuBar::DrawContent(GraphicsEngine &graphics_engine, bool force_draw)
+  void MenuBar::DrawContent(GraphicsEngine &graphics_engine, bool /* force_draw */)
   {
     graphics_engine.PushClippingRectangle(GetGeometry());
     graphics_engine.PopClippingRectangle();
   }
 
-  void MenuBar::PostDraw(GraphicsEngine &graphics_engine, bool force_draw)
-  {
-
-  }
-
   void MenuBar::AddMenu(const char *MenuLabel, MenuPage *menu)
   {
     NUX_RETURN_IF_NULL(menu);
@@ -235,14 +230,13 @@ namespace nux
     GetWindowThread()->ComputeElementLayout(m_hlayout);
   }
 
-  void MenuBar::EmitItemMouseEnter(int x, int y, unsigned long button_flags, unsigned long key_flags, MenuBarItem *menubar_item)
+  void MenuBar::EmitItemMouseEnter(int /* x */, int /* y */, unsigned long /* button_flags */, unsigned long /* key_flags */, MenuBarItem *menubar_item)
   {
     if (m_MenuIsActive)
     {
       if (m_CurrentMenu && (m_CurrentMenu->menu != menubar_item->menu))
         m_CurrentMenu->menu->StopMenu(0, 0);
 
-      Geometry geo = menubar_item->menu->GetGeometry();
       menubar_item->menu->m_MenuWindow = m_MenuBarWindow;
       menubar_item->menu->StartMenu(menubar_item->area->GetBaseX(),
                                      menubar_item->area->GetBaseY() + menubar_item->area->GetBaseHeight(), 0, 0);
@@ -255,11 +249,11 @@ namespace nux
     QueueDraw();
   }
 
-  void MenuBar::EmitItemMouseLeave(int x, int y, unsigned long button_flags, unsigned long key_flags, MenuBarItem *menubar_item)
+  void MenuBar::EmitItemMouseLeave(int /* x */, int /* y */, unsigned long /* button_flags */, unsigned long /* key_flags */, MenuBarItem * /* menubar_item */)
   {
     QueueDraw();
   }
-  void MenuBar::EmitItemMouseDown(int x, int y, unsigned long button_flags, unsigned long key_flags, MenuBarItem *menubar_item)
+  void MenuBar::EmitItemMouseDown(int /* x */, int /* y */, unsigned long /* button_flags */, unsigned long /* key_flags */, MenuBarItem *menubar_item)
   {
     m_MenuBarWindow = GetWindowThread()->GetWindowCompositor().GetProcessingTopView();
 
@@ -290,7 +284,7 @@ namespace nux
     QueueDraw();
   }
 
-  void MenuBar::EmitItemMouseUp(int x, int y, unsigned long button_flags, unsigned long key_flags, MenuBarItem *menubar_item)
+  void MenuBar::EmitItemMouseUp(int x, int y, unsigned long button_flags, unsigned long key_flags, MenuBarItem * /* menubar_item */)
   {
     if (m_MenuIsActive)
     {
@@ -327,7 +321,7 @@ namespace nux
     QueueDraw();
   }
 
-  void MenuBar::RecvItemMouseDrag(int x, int y, int dx, int dy, unsigned long button_flags, unsigned long key_flags, MenuBarItem *menubar_item)
+  void MenuBar::RecvItemMouseDrag(int /* x */, int /* y */, int /* dx */, int /* dy */, unsigned long /* button_flags */, unsigned long /* key_flags */, MenuBarItem * /* menubar_item */)
   {
     // TODO: Port to new event architecture
 //     // Transition between one menu bar item to another
@@ -367,7 +361,7 @@ namespace nux
 //     }
   }
 
-  void MenuBar::RecvSigActionTriggered(MenuPage *menu, ActionItem *action)
+  void MenuBar::RecvSigActionTriggered(MenuPage * /* menu */, ActionItem * /* action */)
   {
     m_MenuIsActive = false;
 
@@ -399,7 +393,7 @@ namespace nux
     QueueDraw();
   }
 
-  void MenuBar::RecvSigMouseDownOutsideMenuCascade(MenuPage *menu, int x, int y)
+  void MenuBar::RecvSigMouseDownOutsideMenuCascade(MenuPage * /* menu */, int x, int y)
   {
     Geometry geometry;
     std::list< MenuBarItem * >::iterator it;
