@@ -33,19 +33,13 @@ namespace nux
   class Panel: public ScrollView
   {
   public:
-    Panel (NUX_FILE_LINE_PROTO);
+    Panel(NUX_FILE_LINE_PROTO);
     ~Panel();
 
-    virtual long ProcessEvent (IEvent &ievent, long TraverseInfo, long ProcessEventInfo);
-
-    virtual void Draw (GraphicsEngine &GfxContext, bool force_draw);
-    virtual void DrawContent (GraphicsEngine &GfxContext, bool force_draw);
-    virtual void PostDraw (GraphicsEngine &GfxContext, bool force_draw);
-
     //void AddWidget(View* ic);
-    void AddWidget (View *ic, int stretchfactor = 1);
-    void AddWidget (std::list<View *> *ViewList);
-    virtual bool SetLayout (Layout *layout);
+    void AddWidget(View *ic, int stretchfactor = 1);
+    void AddWidget(std::list<View *> *ViewList);
+    virtual bool SetLayout(Layout *layout);
     void clearContent();
 
     // Get a change to do any work on an element.
@@ -53,16 +47,19 @@ namespace nux
     virtual void PreLayoutManagement();
     // Get a change to do any work on an element.
     // Here we need to position the header by hand because it is not under the control of vlayout.
-    virtual long PostLayoutManagement (long LayoutResult);
+    virtual long PostLayoutManagement(long LayoutResult);
     // Get a change to do any work on an element.
     // Here we need to position the header by hand because it is not under the control of vlayout.
-    virtual void PositionChildLayout (float offsetX, float offsetY);
+    virtual void ComputeContentPosition(float offsetX, float offsetY);
 
   protected:
-    virtual void ScrollLeft (float stepx, int mousedx);
-    virtual void ScrollRight (float stepx, int mousedx);
-    virtual void ScrollUp (float stepy, int mousedy);
-    virtual void ScrollDown (float stepy, int mousedy);
+    virtual void Draw(GraphicsEngine &graphics_engine, bool force_draw);
+    virtual void DrawContent(GraphicsEngine &graphics_engine, bool force_draw);
+
+    virtual void ScrollLeft(float stepx, int mousedx);
+    virtual void ScrollRight(float stepx, int mousedx);
+    virtual void ScrollUp(float stepy, int mousedy);
+    virtual void ScrollDown(float stepy, int mousedy);
 
     virtual bool AcceptKeyNavFocus();
 
