@@ -154,7 +154,7 @@ namespace nux
     Color const& GetCompletionColor() const;
 
     void SetTextColor(const Color& color);
-    Color const& GetTextColor() const;
+    Color GetTextColor() const;
     void SetFontFamily(const char* font);
     void SetFontSize(double font_size);
     void SetFontOptions(const cairo_font_options_t* options);
@@ -173,6 +173,8 @@ namespace nux
     void MoveCursorToLineStart();
     void MoveCursorToLineEnd();
 
+    void SetToggleCursorVisibilityOnKeyFocus(bool b);
+    bool GetToggleCursorVisibilityOnKeyFocus() const;
 
     /*!
         When the text entry is in single line mode, the keyboard arrow up/down may be used
@@ -227,10 +229,15 @@ namespace nux
     bool PasswordMode() const;
     std::string GetPasswordChar();
 
+    void PreeditStarted();
+    void UpdatePreedit(std::string const& preedit, int cursor);
+    void UpdatePreeditAttribs(PangoAttrList* list);
+    void ClearPreedit();
+
   protected:
     bool _block_focus; // used to selectively ignore focus keyevents
 
-    virtual void GeometryChanged();
+    virtual void GeometryChanged(bool position_has_changed, bool size_has_changed);
 
     /**
      * Enum used to specify different motion types.
@@ -506,6 +513,7 @@ namespace nux
 
     bool lose_key_focus_on_key_nav_direction_up_;
     bool lose_key_focus_on_key_nav_direction_down_;
+    bool cursor_visible_on_key_focus_only_;
 
     std::vector<unsigned long> composition_list_;
 
