@@ -1,5 +1,5 @@
 /*
- * Copyright 2010 Inalogic® Inc.
+ * Copyright 2010-2013 Inalogic® Inc.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License, as
@@ -16,17 +16,17 @@
  * License along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  * Authored by: Jay Taoko <jaytaoko@inalogic.com>
+ *              Marco Trevisan <marco.trevisan@canonical.com>
  *
  */
 
-
 #include "Nux.h"
 #include "TimerProc.h"
 #include "WindowCompositor.h"
 #include "WindowThread.h"
 
 class BaseWindow;
-    
+
 namespace nux
 {
 
@@ -54,73 +54,77 @@ namespace nux
 
     //! Delay before the callback expires
     TimeStruct      when;
+    int             Type;
     gint64          ms_time; // milliseconds 
-    void            *CallbackData;
-    TimeOutSignal    *timeout_signal;
+    void           *CallbackData;
+    TimeOutSignal  *timeout_signal;
 
     //! time progression factor between [0.0, 1.0]
     float           Param;
     float           ProgressDelta;
-    int             Type;
-    int             ScheduledIteration;     //!< The number of scheduled iterations.
-    int             ProgressIterationCount; //!< Number of times the timer has been executed.
     int             Period;                 //!< The periode of the timer interuption(in milliseconds).
     int             Duration;               //!< How long the timer will be running from start to finish(in milliseconds);
     int             ElapsedTime;            //!< Elapsed time during execution(in milliseconds).
+    int             ScheduledIteration;     //!< The number of scheduled iterations.
+    int             ProgressIterationCount; //!< Number of times the timer has been executed.
     bool            marked_for_removal_;
     BaseWindow      *Window;                 //!< BaseWindow from where the timer was created.
-    TimerObject     *next;
-    TimerObject     *prev;
     unsigned int           glibid;
     unsigned int           uid;
     TimerHandler::TimerState      state_;
   };
 
   TimerObject::TimerObject()
-  {
-    ms_time         = 0;
-    Type            = 0;
-    CallbackData    = 0;
-    timeout_signal   = 0;
-    Param           = 0;
-    Period          = 0;
-    Duration        = 0;
-    ElapsedTime     = 0;
-    ScheduledIteration       = 0;
-    ProgressIterationCount  = 0;
-    marked_for_removal_ = 0;
-    Window          = 0;
-    next            = 0;
-    prev            = 0;
-    glibid          = 0;
-    uid             = 0;
-    state_          = TimerHandler::TIMER_STATE_STOPED;
-  }
+    : Type(0)
+    , ms_time(0)
+    , CallbackData(nullptr)
+    , timeout_signal(nullptr)
+    , Param(0)
+    , ProgressDelta(0)
+    , Period(0)
+    , Duration(0)
+    , ElapsedTime(0)
+    , ScheduledIteration(0)
+    , ProgressIterationCount(0)
+    , marked_for_removal_(0)
+    , Window(nullptr)
+    , glibid(0)
+    , uid(0)
+    , state_(TimerHandler::TIMER_STATE_STOPED)
+  {}
 
   TimerHandle::TimerHandle()
-  {
-    m_d = 0;
-  }
+  {}
 
   TimerHandle::TimerHandle(TimerObject *timer_object)
-  {
-    m_d = timer_object;
-  }
-
-  TimerHandle::~TimerHandle()
-  {
-    m_d = 0;
-  }
+    : m_d(timer_object)
+  {}
 
   TimerHandle::TimerHandle(const TimerHandle &timer_handle)
+    : m_d(timer_handle.m_d)
+  {}
+
+  TimerHandle& TimerHandle::operator = (const TimerHandle &timer_handle)
   {
-    m_d = timer_handle.m_d;
+    TimerHandle copy(timer_handle);
+    std::swap(m_d, copy.m_d);
+
+    return *this;
   }
 
-  TimerHandle &TimerHandle::operator = (const TimerHandle &timer_handle)
+  std::shared_ptr<TimerObject> const& TimerHandle::operator->() const
   {
-    m_d = timer_handle.m_d;
-    return *this;
+    return m_d;
+  }
+
+  bool TimerHandle::operator==(TimerHandle const& h) const
+  {
+    bool equal = (m_d == h.m_d);
+
+    if (equal && m_d)
+      equal = (m_d->uid == h.m_d->uid);
+
+    return equal;
   }
 
   bool TimerHandle::IsValid() const
@@ -130,7 +134,7 @@ namespace nux
 
   bool TimerHandle::Activated() const
   {
-    return m_d != 0;
+    return m_d != nullptr;
   }
 
   float TimerHandle::GetProgress() const
@@ -172,20 +176,12 @@ namespace nux
   TimerHandler::TimerHandler(WindowThread* window_thread)
   : window_thread_(window_thread)
   , is_processing_timers_(false)
-  , timer_object_queue_(NULL)
-  {
-  }
-
-  TimerHandler::~TimerHandler()
-  {
-  }
+  {}
 
   void TimerHandler::StartEarlyTimerObjects()
   {
-    std::list<TimerObject*>::iterator it;
-    for (it = _early_timer_objects.begin(); it != _early_timer_objects.end(); it++)
+    for (auto const& timer_object : early_timer_handlers_)
     {
-      TimerObject *timer_object = *it;
       timer_object->ms_time = g_get_monotonic_time() / 1000;
 
 #if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
@@ -193,12 +189,12 @@ namespace nux
 #endif
     }
 
-    _early_timer_objects.clear();
+    early_timer_handlers_.clear();
   }
 
   TimerHandle TimerHandler::AddOneShotTimer(unsigned int Period, TimeOutSignal* timeout_signal, void* Data, WindowThread* window_thread)
   {
-    TimerObject *timer_object = new TimerObject();
+    TimerHandle timer_object(new TimerObject);
 
     timer_object->ms_time = g_get_monotonic_time() / 1000;
 
@@ -211,7 +207,7 @@ namespace nux
       timer_object->Window        = window_thread->GetWindowCompositor().GetProcessingTopView();
     else
       timer_object->Window        = GetWindowThread()->GetWindowCompositor().GetProcessingTopView();
-    
+
     AddHandle(timer_object);
 
 #if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
@@ -220,10 +216,10 @@ namespace nux
         timer_object->glibid = window_thread->AddTimeout(Period);
       else
         timer_object->glibid = GetWindowThread()->AddTimeout(Period);
-      
+
       if (timer_object->glibid == 0)
       {
-        _early_timer_objects.push_back(timer_object);
+        early_timer_handlers_.push_back(timer_object);
         // Probably trying to set a timeout before Glib main context and loop have been created.
         // Sometimes later, this timer will be examined when ExecTimerHandler is called.
         // This happens when trying to set a callback before the main loop has been initialized.
@@ -233,13 +229,12 @@ namespace nux
     }
 #endif
 
-    TimerHandle handle(timer_object);
-    return handle;
+    return timer_object;
   }
 
   TimerHandle TimerHandler::AddDurationTimer(unsigned int Period, int Duration, TimeOutSignal *timeout_signal, void *Data)
   {
-    TimerObject* timer_object = new TimerObject();
+    TimerHandle timer_object(new TimerObject);
 
     timer_object->ms_time = g_get_monotonic_time() / 1000;
     timer_object->CallbackData = Data;
@@ -257,7 +252,7 @@ namespace nux
 
       if (timer_object->glibid == 0)
       {
-        _early_timer_objects.push_back(timer_object);
+        early_timer_handlers_.push_back(timer_object);
         // Probably trying to set a timeout before Glib main context and loop have been created.
         // Sometimes later, this timer will be examined when ExecTimerHandler is called.
         // This happens when trying to set a callback before the mainloop has been initialized.
@@ -267,13 +262,12 @@ namespace nux
     }
 #endif
 
-    TimerHandle handle(timer_object);
-    return handle;
+    return timer_object;
   }
 
   TimerHandle TimerHandler::AddIterativeTimer(unsigned int Period, int NumberOfIterations, TimeOutSignal *timeout_signal, void *Data)
   {
-    TimerObject* timer_object = new TimerObject();
+    TimerHandle timer_object(new TimerObject);
 
     timer_object->ms_time = g_get_monotonic_time() / 1000;
     timer_object->CallbackData = Data;
@@ -291,7 +285,7 @@ namespace nux
 
       if (timer_object->glibid == 0)
       {
-        _early_timer_objects.push_back(timer_object);
+        early_timer_handlers_.push_back(timer_object);
         // Probably trying to set a timeout before Glib main context and loop have been created.
         // Sometimes later, this timer will be examined when ExecTimerHandler is called.
         // This happens when trying to set a callback before the mainloop has been initialized.
@@ -300,111 +294,53 @@ namespace nux
       //nuxDebugMsg("[TimerHandler::AddOneShotTimer] Adding Timeout ID: %d", timer_object->glibid);
     }
 #endif
-    TimerHandle handle(timer_object);
-    return handle;
+
+    return timer_object;
   }
 
 // Sort timers and add them to the queue
-  TimerObject *TimerHandler::AddHandle(TimerObject* timer_object)
+  void TimerHandler::AddHandle(TimerHandle const& timer_handle)
   {
-    if (timer_object == NULL)
-      return NULL;
+    if (!timer_handle.Activated())
+      return;
 
     // Give the Timer a unique ID;
-    timer_object->uid = TimerUID.GetValue();
+    timer_handle->uid = TimerUID.GetValue();
     TimerUID.Increment();
 
-    // If the queue is empty or the new timer will expire sooner than the first timer in the queue
-    // then add the new timer at the start of the queue.
-    if ((timer_object_queue_ == NULL) || (timer_object_queue_->ms_time > timer_object->ms_time))
-    {
-      // Add the timer timer_object at the head of the queue
-      timer_object->next = timer_object_queue_;
+    auto tmp = timer_handler_queue_.begin();
 
-      if (timer_object_queue_)
-        timer_object_queue_->prev = timer_object;
+    while (tmp != timer_handler_queue_.end() && timer_handle->ms_time >= (*tmp)->ms_time)
+      ++tmp;
 
-      timer_object->prev = 0;
-      timer_object_queue_ = timer_object;
-
-      return timer_object;
-    }
-
-    TimerObject *tmp = timer_object_queue_;
-
-    while (tmp->next != NULL)
-    {
-      // Is the time to wait for tmp->next to expire smaller than for timer_object
-      if (timer_object->ms_time > tmp->next->ms_time)
-      {
-        // keep searching
-        tmp = tmp->next;
-      }
-      else
-      {
-        timer_object->next = tmp->next;
-        tmp->next->prev = timer_object;
-        tmp->next = timer_object;
-        timer_object->prev = tmp;
-        return timer_object;
-      }
-    }
-
-    tmp->next = timer_object;
-    timer_object->next = NULL;
-    timer_object->prev = tmp;
-    return timer_object;
+    timer_handler_queue_.insert(tmp, timer_handle);
   }
 
   unsigned int TimerHandler::GetNumPendingHandler()
   {
-    unsigned int count = 0;
-    TimerObject *head = timer_object_queue_;
-
-    while (head)
-    {
-      count++;
-      head = head->next;
-    }
-
-    return count;
+    return timer_handler_queue_.size();
   }
 
   bool TimerHandler::RemoveTimerHandler(TimerHandle &handle)
   {
-    NUX_RETURN_VALUE_IF_NULL(handle.m_d, false);
-    NUX_RETURN_VALUE_IF_NULL(timer_object_queue_, false);
+    if (!handle.Activated() || timer_handler_queue_.empty())
+      return false;
 
-    TimerObject* tmp;
-
-    tmp = timer_object_queue_;
-
-    while (tmp)
+    for (auto it = timer_handler_queue_.begin(); it != timer_handler_queue_.end(); ++it)
     {
-      if ((tmp == handle.m_d) && (tmp->uid == handle.m_d->uid))
+      if (*it == handle)
       {
         if (!is_processing_timers_)
         {
-          if (tmp->next)
-            tmp->next->prev = tmp->prev;
-
-          if (tmp->prev)
-            tmp->prev->next = tmp->next;
-
-          if ((handle.m_d == timer_object_queue_) && (handle.m_d->uid == timer_object_queue_->uid))
-            timer_object_queue_ = handle.m_d->next;
-
-          NUX_SAFE_DELETE(handle.m_d);
+          handle = nullptr;
+          timer_handler_queue_.erase(it);
+          return true;
         }
         else
         {
-          handle.m_d->marked_for_removal_ = true;
+          handle->marked_for_removal_ = true;
         }
-
-        return true;
       }
-
-      tmp = tmp->next;
     }
 
     return false;
@@ -412,115 +348,95 @@ namespace nux
 
   bool TimerHandler::PauseTimer(TimerHandle& handle)
   {
-    NUX_RETURN_VALUE_IF_NULL(handle.m_d, false);
-    NUX_RETURN_VALUE_IF_NULL(timer_object_queue_, false);
-
-    if (handle.m_d->state_ != TimerHandler::TIMER_STATE_RUNNING)
-    {
+    if (!handle.Activated() || timer_handler_queue_.empty())
       return false;
-    }
 
-    TimerObject* tmp;
+    if (handle->state_ != TimerHandler::TIMER_STATE_RUNNING)
+      return false;
 
-    // Pointer to the start of the queue.
-    tmp = timer_object_queue_;
-
-    // Search for the timer handle
-    while (tmp)
+    for (auto const& h : timer_handler_queue_)
     {
-      if ((tmp == handle.m_d) && (tmp->uid == handle.m_d->uid))
+      if (h == handle)
       {
-        handle.m_d->state_ = TimerHandler::TIMER_STATE_PAUSED;
-
+        handle->state_ = TimerHandler::TIMER_STATE_PAUSED;
 
         if (!is_processing_timers_)
         {
           gint64 ms_time_now = g_get_monotonic_time() / 1000;
-          
-          if (handle.m_d->Type == TIMERTYPE_PERIODIC)
+
+          if (handle->Type == TIMERTYPE_PERIODIC)
           {
-            handle.m_d->ElapsedTime += (ms_time_now - handle.m_d->ms_time);
-            handle.m_d->ProgressDelta = float(handle.m_d->ElapsedTime) / float(handle.m_d->Period);
+            handle->ElapsedTime += (ms_time_now - handle->ms_time);
+            handle->ProgressDelta = float(handle->ElapsedTime) / float(handle->Period);
 
-            if (handle.m_d->Param + handle.m_d->ProgressDelta > 1.0f)
-              handle.m_d->ProgressDelta = 1.0f - handle.m_d->Param;
+            if (handle->Param + handle->ProgressDelta > 1.0f)
+              handle->ProgressDelta = 1.0f - handle->Param;
 
-            handle.m_d->Param = float(handle.m_d->ElapsedTime) / float(handle.m_d->Period);
+            handle->Param = float(handle->ElapsedTime) / float(handle->Period);
           }
         }
 
         return true;
       }
-
-      tmp = tmp->next;
     }
+
     return false;
   }
 
   bool TimerHandler::ResumeTimer(TimerHandle& handle)
   {
-    NUX_RETURN_VALUE_IF_NULL(handle.m_d, false);
-    NUX_RETURN_VALUE_IF_NULL(timer_object_queue_, false);
-
-    if (handle.m_d->state_ != TimerHandler::TIMER_STATE_PAUSED)
-    {
+    if (handle.Activated() || timer_handler_queue_.empty())
       return false;
-    }
 
-    TimerObject* tmp;
+    if (handle->state_ != TimerHandler::TIMER_STATE_PAUSED)
+      return false;
 
-    // Pointer to the start of the queue.
-    tmp = timer_object_queue_;
-
-    // Search for the timer handle
-    while (tmp)
+    for (auto const& h : timer_handler_queue_)
     {
-      if ((tmp == handle.m_d) && (tmp->uid == handle.m_d->uid))
+      if (h == handle)
       {
-        handle.m_d->state_ = TimerHandler::TIMER_STATE_RUNNING;
+        handle->state_ = TimerHandler::TIMER_STATE_RUNNING;
 
-        if (handle.m_d->Type == TIMERTYPE_PERIODIC)
+        if (handle->Type == TIMERTYPE_PERIODIC)
         {
-          handle.m_d->glibid = GetWindowThread()->AddTimeout(handle.m_d->Period * (1.0f - handle.m_d->Param));
+          handle->glibid = GetWindowThread()->AddTimeout(handle->Period * (1.0f - handle->Param));
         }
         else
         {
-          handle.m_d->glibid = GetWindowThread()->AddTimeout(handle.m_d->Period);
+          handle->glibid = GetWindowThread()->AddTimeout(handle->Period);
         }
 
-        handle.m_d->ms_time = g_get_monotonic_time() / 1000;
+        handle->ms_time = g_get_monotonic_time() / 1000;
+
+        if (handle->glibid == 0)
+          early_timer_handlers_.push_back(handle);
 
-        if (handle.m_d->glibid == 0)
-        {
-          _early_timer_objects.push_back(handle.m_d);
-        }
         return true;
       }
-
-      tmp = tmp->next;
     }
+
     return false;
   }
 
   int TimerHandler::ExecTimerHandler(unsigned int timer_id)
   {
-    NUX_RETURN_VALUE_IF_NULL(timer_object_queue_, 0);
+    if (timer_handler_queue_.empty())
+      return 0;
 
     bool repeat = false;
-    // Pointer to the start of the timer handler queue.
-    TimerObject* timer_object = timer_object_queue_;
-
     is_processing_timers_ = true;
 
-    while (timer_object != NULL)
+    for (auto it = timer_handler_queue_.begin(); it != timer_handler_queue_.end(); ++it)
     {
-      if ((timer_object->glibid == timer_id) && (timer_object->marked_for_removal_ == false))
+      auto const& timer_object = *it;
+
+      if (timer_object->glibid == timer_id && !timer_object->marked_for_removal_)
       {
         if (timer_object->state_ != TIMER_STATE_RUNNING)
         {
           return false;
         }
-        // Find the first timer object that 
+        // Find the first timer object that
 
         timer_object->ElapsedTime += timer_object->Period;
 
@@ -562,7 +478,6 @@ namespace nux
           nuxAssertMsg(0, "[TimerHandler::ExecTimerHandler] Unknown timer type.");
         }
 
-
         if (timer_object->Param > 1.0f)
         {
           // correction.
@@ -571,39 +486,39 @@ namespace nux
 
         timer_object->marked_for_removal_ = false;
 
-        if (timer_object->timeout_signal != 0)
+        if (timer_object->timeout_signal)
         {
           // Execute the signal
           GetWindowThread()->GetWindowCompositor().SetProcessingTopView(timer_object->Window);
           timer_object->timeout_signal->tick.emit(timer_object->CallbackData);
-          GetWindowThread()->GetWindowCompositor().SetProcessingTopView(NULL);          
+          GetWindowThread()->GetWindowCompositor().SetProcessingTopView(NULL);
           // Reset glibid to 0. glibid is not null, if this element ever happened to be at the head of the queue
           // and we set a timer for it.
           //nuxDebugMsg("[TimerHandler::ExecTimerHandler] Executed Timeout ID: %d", timer_object->glibid);
           //timer_object->glibid = 0;
         }
 
-        TimerObject* expired_handler = 0;
+        bool expired_handler = false;
 
         if (timer_object->marked_for_removal_)
         {
           // RemoveTimerHandler was called during the callback execution
-          expired_handler = timer_object;
+          expired_handler = true;
         }
         else if (timer_object->Type == TIMERTYPE_PERIODIC)
         {
           // A one shot timer expires after the first execution.
-          expired_handler = timer_object;
+          expired_handler = true;
         }
         else if ((timer_object->Type == TIMERTYPE_DURATION) && (timer_object->Param >= 1.0f))
         {
           // A timer delay timer expires after the duration of the timer as expired.
-          expired_handler = timer_object;
+          expired_handler = true;
         }
         else if ((timer_object->Type == TIMERTYPE_ITERATION) && (timer_object->ProgressIterationCount >= timer_object->ScheduledIteration))
         {
           // An iterative timer expires after the timer as been executedN times.
-          expired_handler = timer_object;
+          expired_handler = true;
         }
 
         if (!expired_handler && (timer_object->state_ == TIMER_STATE_PAUSED))
@@ -612,33 +527,17 @@ namespace nux
           return false;
         }
 
-        if(expired_handler)
+        if (expired_handler)
         {
-          GetWindowThread()->GetWindowCompositor().SetProcessingTopView(timer_object->Window);
-          timer_object->timeout_signal->expired.emit(timer_object->CallbackData);
-          GetWindowThread()->GetWindowCompositor().SetProcessingTopView(NULL);          
-
-          timer_object->state_ = TIMER_STATE_STOPED;
-
-          if (timer_object->next)
-            timer_object->next->prev = timer_object->prev;
-
-          if (timer_object->prev)
-            timer_object->prev->next = timer_object->next;
-
-          if ((timer_object == timer_object_queue_) && (timer_object->uid == timer_object_queue_->uid))
+          if (timer_object->timeout_signal)
           {
-            // timer_object is the first element of the queue.
-            timer_object_queue_ = timer_object->next;
-
-            if (timer_object_queue_)
-            {
-              timer_object_queue_->prev = 0;
-            }
+            GetWindowThread()->GetWindowCompositor().SetProcessingTopView(timer_object->Window);
+            timer_object->timeout_signal->expired.emit(timer_object->CallbackData);
+            GetWindowThread()->GetWindowCompositor().SetProcessingTopView(NULL);
           }
 
-          timer_object = timer_object->next;
-          delete expired_handler;
+          timer_object->state_ = TIMER_STATE_STOPED;
+          timer_handler_queue_.erase(it);
         }
         else
         {
@@ -647,44 +546,20 @@ namespace nux
 
         break;
       }
-      else
-      {
-        timer_object = timer_object->next;
-      }
     }
 
     // Purge handles that have been marked for removal
-    timer_object = timer_object_queue_;
-
-    while (timer_object)
+    for (auto it = timer_handler_queue_.begin(); it != timer_handler_queue_.end();)
     {
+      auto const& timer_object = *it;
+
       if (timer_object->marked_for_removal_)
       {
-        TimerObject* expired_handler = timer_object;
-
-        if (timer_object->next)
-          timer_object->next->prev = timer_object->prev;
-
-        if (timer_object->prev)
-          timer_object->prev->next = timer_object->next;
-        else
-        {
-          // timer_object is the first element of the queue.
-          timer_object_queue_ = timer_object->next;
-
-          if (timer_object_queue_)
-          {
-            timer_object_queue_->prev = 0;
-          }
-        }
-
-        timer_object = timer_object->next;
-        delete expired_handler;
-      }
-      else
-      {
-        timer_object = timer_object->next;
+        it = timer_handler_queue_.erase(it);
+        continue;
       }
+
+      ++it;
     }
 
     is_processing_timers_ = false;
@@ -693,54 +568,40 @@ namespace nux
 
   bool TimerHandler::FindTimerHandle(TimerHandle &timer_object)
   {
-    TimerObject *tmp = timer_object_queue_;
+    auto it = std::find(timer_handler_queue_.begin(), timer_handler_queue_.end(), timer_object);
 
-    while (tmp)
-    {
-      if (tmp == timer_object.m_d && (tmp->uid == timer_object.m_d->uid))
-      {
-        return true;
-      }
-
-      tmp = tmp->next;
-    }
-
-    return false;
+    return (it != timer_handler_queue_.end());
   }
 
 //----------------------------------------------------------------------------
   int TimerHandler::DelayUntilNextTimerExpires()
   {
+    if (timer_handler_queue_.empty())
+      return 0;
+
     TimeStruct now;
     TimeStruct delay;
 
-    if (timer_object_queue_ == NULL)
+    TimeRightNow(&now);
+    auto const& first = timer_handler_queue_.front();
+
+    if (TimeIsGreater(now, first->when))
     {
-      // The return value of this function is only valid if there _are_ timers active.
       return 0;
     }
     else
     {
-      TimeRightNow(&now);
+      delay.sec = first->when.sec - now.sec;
+      delay.usec = first->when.usec - now.usec;
 
-      if (TimeIsGreater(now, timer_object_queue_->when))
+      // make sure that usec cannot be less than -1000000 before applying this code
+      if (delay.usec < 0)
       {
-        return 0;
+        delay.usec += 1000000;
+        delay.sec--;
       }
-      else
-      {
-        delay.sec = timer_object_queue_->when.sec - now.sec;
-        delay.usec = timer_object_queue_->when.usec - now.usec;
 
-        // make sure that usec cannot be less than -1000000 before applying this code
-        if (delay.usec < 0)
-        {
-          delay.usec += 1000000;
-          delay.sec--;
-        }
-
-        return  (delay.sec * 1000000 + delay.usec) / 1000; // return delay in milliseconds
-      }
+      return  (delay.sec * 1000000 + delay.usec) / 1000; // return delay in milliseconds
     }
   }
 
