@@ -1,5 +1,5 @@
 /*
- * Copyright 2010 Inalogic® Inc.
+ * Copyright 2010, 2012 Inalogic® Inc.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License, as
@@ -31,12 +31,11 @@ namespace nux
 
   View::View(NUX_FILE_LINE_DECL)
   : InputArea(NUX_FILE_LINE_PARAM)
-//   , redirect_rendering_to_texture_(false)
-//   , update_backup_texture_(false)
+  , m_TextColor(1.0f, 1.0f, 1.0f, 1.0f)
+  , view_layout_(nullptr)
+  , draw_cmd_queued_(false)
+  , child_draw_cmd_queued_(false)
   {
-    view_layout_      = NULL;
-    draw_cmd_queued_  = false;
-    m_TextColor       = Color(1.0f, 1.0f, 1.0f, 1.0f);
   }
 
   View::~View()
@@ -172,16 +171,12 @@ namespace nux
         {
           graphics_engine.PushModelViewMatrix(Get2DMatrix());
 
-          Geometry translated_geo = GetGeometry();
-          translated_geo.x = 0;
-          translated_geo.y = 0;
           if (force_draw)
           {
             draw_cmd_queued_ = true;
             full_view_draw_cmd_ = true;
             Draw(graphics_engine, force_draw);
             DrawContent(graphics_engine, force_draw);
-            PostDraw(graphics_engine, force_draw);
           }
           else
           {
@@ -190,12 +185,10 @@ namespace nux
               full_view_draw_cmd_ = true;
               Draw(graphics_engine, false);
               DrawContent(graphics_engine, false);
-              PostDraw(graphics_engine, false);
             }
             else if (update_backup_texture_)
             {
               DrawContent(graphics_engine, false);
-              PostDraw(graphics_engine, false);
             }
           }
           graphics_engine.PopModelViewMatrix();
@@ -245,7 +238,6 @@ namespace nux
         full_view_draw_cmd_ = true;
         Draw(graphics_engine, force_draw);
         DrawContent(graphics_engine, force_draw);
-        PostDraw(graphics_engine, force_draw);
 
         GetPainter().PopPaintLayerStack();
       }
@@ -259,14 +251,12 @@ namespace nux
           full_view_draw_cmd_ = true;
           Draw(graphics_engine, false);
           DrawContent(graphics_engine, false);
-          PostDraw(graphics_engine, false);
 
           GetPainter().PopPaintLayerStack();
         }
         else
         {
           DrawContent(graphics_engine, false);
-          PostDraw(graphics_engine, false);
         }
       }
 
@@ -402,7 +392,7 @@ namespace nux
 
   }
 
-  void View::EndBackupTextureRendering(GraphicsEngine& graphics_engine, bool force_draw)
+  void View::EndBackupTextureRendering(GraphicsEngine& graphics_engine, bool /* force_draw */)
   {
     graphics_engine.PopModelViewMatrix();
 
@@ -423,23 +413,25 @@ namespace nux
     graphics_engine.SetViewport(prev_viewport_.x, prev_viewport_.y, prev_viewport_.width, prev_viewport_.height);
   }
 
-  void View::Draw(GraphicsEngine &graphics_engine, bool force_draw)
+  void View::Draw(GraphicsEngine & /* graphics_engine */, bool /* force_draw */)
   {
 
   }
 
-  void View::DrawContent(GraphicsEngine &graphics_engine, bool force_draw)
-  {
-
-  }
-
-  void View::PostDraw(GraphicsEngine &graphics_engine, bool force_draw)
+  void View::DrawContent(GraphicsEngine & /* graphics_engine */, bool /* force_draw */)
   {
 
   }
 
   void View::QueueDraw()
   {
+    // Report to a parent view with redirect_rendering_to_texture_ set to true that one of its children
+    // needs to be redrawn.
+    //
+    // We should always do this, as the conditions for parent rendering may have
+    // changed between child QueueDraw calls (eg window visibility)
+    PrepareParentRedirectedView();
+
     if (draw_cmd_queued_)
       return;
 
@@ -449,10 +441,6 @@ namespace nux
       application->AddToDrawList(this);
       application->RequestRedraw();
     }
-    
-    // Report to a parent view with redirect_rendering_to_texture_ set to true that one of its children
-    // needs to be redrawn.
-    PrepareParentRedirectedView();
 
     if (view_layout_)
     {
@@ -626,7 +614,7 @@ namespace nux
     m_TextColor = color;
   }
 
-  Color View::GetTextColor()
+  Color View::GetTextColor() const
   {
     return m_TextColor;
   }
@@ -658,13 +646,13 @@ namespace nux
     return view_enabled_;
   }
 
-  void View::GeometryChangePending(bool position_about_to_change, bool size_about_to_change)
+  void View::GeometryChangePending(bool /* position_about_to_change */, bool /* size_about_to_change */)
   {
     if (IsLayoutDone())
       QueueDraw();
   }
 
-  void View::GeometryChanged(bool position_has_changed, bool size_has_changed)
+  void View::GeometryChanged(bool /* position_has_changed */, bool size_has_changed)
   {
     if (RedirectedAncestor())
     {
