@@ -23,6 +23,8 @@
 #ifndef WINDOWCOMPOSITOR_H
 #define WINDOWCOMPOSITOR_H
 
+#include <functional>
+
 #include "BaseWindow.h"
 
 #include <sigc++/trackable.h>
@@ -43,6 +45,7 @@ namespace nux
   class WindowThread;
   class View;
   class InputArea;
+  class InputAreaProximity;
   class Area;
   class PaintLayer;
   class Event;
@@ -52,6 +55,7 @@ namespace nux
   {
   public:
     typedef ObjectWeakPtr<BaseWindow> WeakBaseWindowPtr;
+    typedef std::function <void(WeakBaseWindowPtr const&)> ForEachBaseWindowFunc;
 
     WindowCompositor(WindowThread* window_thread);
     ~WindowCompositor();
@@ -72,20 +76,25 @@ namespace nux
     //====================================
     void MouseEventCycle(Event& event);
     void DndEventCycle(Event& event);
-    bool _enable_nux_new_event_architecture;
-
 
     Point _mouse_position_on_owner;
     Point _mouse_position;
 
     //! Get Mouse position relative to the top left corner of the window.
     Point GetMousePosition();
-    
+
+    int GetProximityListSize() const;
+    void AddAreaInProximityList(InputAreaProximity* area_prox);
+    void RemoveAreaInProximityList(InputAreaProximity* area_prox);
+
     void KeyboardEventCycle(Event& event);
 
+#if !defined(NUX_MINIMAL)
     void MenuEventCycle(Event& event);
     MenuPage* _mouse_owner_menu_page;
     MenuPage* _mouse_over_menu_page;
+#endif
+
     bool      _starting_menu_event_cycle;
     bool      _menu_is_active;
 
@@ -106,9 +115,11 @@ namespace nux
         Return the area that has the keyboard focus.
 
         @return The area that has the keyboard focus.
-    */    
+    */
     InputArea* GetKeyFocusArea();
 
+    void ForEachBaseWindow(ForEachBaseWindowFunc const&);
+
     //! Signal emitted when a BaseWindow becomes visible.
     /*!
         This signal is emitted after the BaseWindow has emitted it own sigVisible signal. 
@@ -122,19 +133,41 @@ namespace nux
     sigc::signal<void, BaseWindow*> sigHiddenViewWindow;    //!< Signal emitted when the BaseWindow becomes hidden.
 
   private:
+    /*** Helper functions for MouseEventCycle() ***/
+    void UpdateKeyNavFocusOnMouseDown();
+    /* Keeps track of mouse movement and emits mouse_move and mouse_drag
+       accordingly. */
+    void TrackMouseMovement(const Event &event, bool area_under_mouse_changed);
+    /* Updates mouse_over_area_ and emits mouse_enter and mouse_leave signals
+       accordingly. Returns whether mouse_over_area_ has changed */
+    bool UpdateWhatAreaIsUnderMouse(const Event& event);
+    /* Processes NUX_MOUSEWHEEL events */
+    void ProcessMouseWheelEvent(Event& event);
+    /* Updates mouse_owner_area_ and emits mouse_down, mouse_up, mouse_click
+       and mouse_double_click accordingly. */
+    void UpdateMouseOwner(const Event& event, bool area_under_mouse_changed);
+    /*
+       Feed the appropriate InputArea::ChildMouseEvent() and switch mouse ownership
+       (including the emission of mouse_cancel) if asked to.
+      */
+    void UpdateEventTrackingByMouseOwnerAncestor(const Event& event);
+    void FindAncestorInterestedInChildMouseEvents(Area *area);
 
     //! Traverse the widget tree and found the area that is right below the mouse pointer.
+    void FindAreaUnderMouse(const Point& mouse_position,
+                           NuxEventType event_type,
+                           ObjectWeakPtr<InputArea>& area_under_mouse_pointer);
     void GetAreaUnderMouse(const Point& mouse_position,
                            NuxEventType event_type,
                            ObjectWeakPtr<InputArea>& area_under_mouse_pointer,
-                           ObjectWeakPtr<BaseWindow>& window);
+                           WeakBaseWindowPtr& window);
 
     //! Traverse the widget tree and found the area has the key focus.
     void FindKeyFocusArea(NuxEventType event_type,
                           unsigned int key_symbol,
                           unsigned int special_keys_state,
                           ObjectWeakPtr<InputArea>& key_focus_area,
-                          ObjectWeakPtr<BaseWindow>& window);
+                          WeakBaseWindowPtr& window);
 
     //! Traverse the widget tree and found the area has the key focus, but start from a specified widget.
     void FindKeyFocusAreaFrom(NuxEventType event_type,
@@ -142,7 +175,7 @@ namespace nux
       unsigned int special_keys_state,
       InputArea* root_search_area,
       ObjectWeakPtr<InputArea>& key_focus_area,
-      ObjectWeakPtr<BaseWindow>& window);
+      WeakBaseWindowPtr& window);
 
     void ResetMousePointerAreas();
 
@@ -155,16 +188,15 @@ namespace nux
     //! Set the area that is right below the mouse pointer.
     void SetMouseOverArea(InputArea* area);
 
-    //! Set The BaseWindow of the area that is the mouse owner.
-    void SetMouseOwnerBaseWindow(BaseWindow* base_window);
-
     void SendKeyEvent(InputArea* input_area, NuxEventType event_type,
       unsigned int key_sym,
       unsigned long x11_key_code,
       unsigned long special_keys_state,
       const char* text,
       int key_repeat_count);
-
+    
+    //! Checks the list of porximities to see if the mouse is near any areas. 
+    void CheckMouseNearArea(Event const& event);
 
     //! The InputArea that has the keyboard navigation focus.
     /*!
@@ -174,11 +206,19 @@ namespace nux
     ObjectWeakPtr<InputArea> key_focus_area_;
     ObjectWeakPtr<InputArea> mouse_owner_area_;
     ObjectWeakPtr<InputArea> mouse_over_area_;
-    ObjectWeakPtr<BaseWindow> mouse_owner_base_window_;
+
+    /* An ancestor of the current mouse owner area that wants to be notified
+       about all mouse events that a descendant receives and optionally
+       take ownership over the mouse at any given moment.
+       \sa InputArea::ChildMouseEvent()
+     */
+    /* TODO: Make it a list/vector once the need for nested trackers. */
+    ObjectWeakPtr<InputArea> interested_mouse_owner_ancestor_;
 
     int dnd_safety_x_;
     int dnd_safety_y_;
 
+  public:
     /*!
         This signal is similar to Area::key_nav_focus_change. It is emitted from the WindowCompositor.
         The user only needs to listen to this signal to find out the area that has received the keyboard focus.\n
@@ -204,10 +244,11 @@ namespace nux
         restored after Nux completes it rendering. The external fbo is used only in embedded mode. \n
         If the fbo_object parameter 0, then the reference fbo is invalid and will not be used.
 
-        @param fbo_object The opengl index of the fbo.
+        @param draw_fbo_object The opengl index of the GL_DRAW_FRAMEBUFFER_EXT.
+        @param read_fbo_object The opengl index of the GL_READ_FRAMEBUFFER_EXT.
         @param fbo_geometry The geometry of the fbo.
     */
-    void SetReferenceFramebuffer(unsigned int fbo_object, Geometry fbo_geometry);
+    void SetReferenceFramebuffer(unsigned int draw_fbo_object, unsigned int read_fbo_object, const Geometry &fbo_geometry);
 
     /*!
         Bind the reference opengl framebuffer object.
@@ -224,14 +265,16 @@ namespace nux
     
     ObjectPtr<IOpenGLFrameBufferObject> m_FrameBufferObject;
 
-    void StartModalWindow(ObjectWeakPtr<BaseWindow>);
-    void StopModalWindow(ObjectWeakPtr<BaseWindow>);
+    void StartModalWindow(WeakBaseWindowPtr);
+    void StopModalWindow(WeakBaseWindowPtr);
 
+#if !defined(NUX_MINIMAL)
     void AddMenu(MenuPage* menu, BaseWindow* window, bool OverrideCurrentMenuChain = true);
     void RemoveMenu(MenuPage* menu);
     void CleanMenu();
+#endif
 
-    void PushModalWindow(ObjectWeakPtr<BaseWindow> window);
+    void PushModalWindow(WeakBaseWindowPtr window);
 
     void SetWidgetDrawingOverlay(InputArea* ic, BaseWindow* OverlayWindow);
     InputArea* GetWidgetDrawingOverlay();
@@ -253,46 +296,13 @@ namespace nux
     bool IsTooltipActive();
     void CancelTooltip();
 
-    void SetAreaEventRoot(int x, int y)
-    {
-      _event_root = Point(x, y);
-    }
-
     void SetBackgroundPaintLayer(AbstractPaintLayer* bkg);
 
     /*!
         A special BaseWindow that is always on top of all other BaseWindow. It is even above the BaseWindow that is selected.
-        \sa m_SelectedWindow, \sa GetSelectedWindow.
     */
     void SetAlwaysOnFrontWindow(BaseWindow* window);
 
-
-    //! Enable the exclusive event input mode.
-    /*!
-        Set the exclusive event input area(\sa _exclusive_input_area). The greedy input area gets all input events(mouse and keyboard).
-        The exclusive input mode can only be set if there is no exclusive input area already set.
-        To disable the exclusive input move, call DisableExclusiveInputArea with the current exclusive input area as parameter.
-        The exclusive event input mode can only change once during the processing of one event. The change it again, 
-        you have to wait for the next event cycle.
-        \sa DisableExclusiveInputArea.
-        @return True, if the exclusive input mode was enabled.
-    */
-    bool EnableExclusiveInputArea(InputArea* input_area);
-    
-    //! Disable the exclusive event input mode.
-    /*!
-        Disable the exclusive event input mode. It can only be disable if the current exclusive input area is passed as parameter.
-        \sa EnableExclusiveInputArea.
-        @return True, if the exclusive input mode was disabled.
-    */
-    bool DisableExclusiveInputArea(InputArea* input_area);
-
-    //! Return true if the system is in exclusive input event mode.
-    /*!
-        @return True if the system is in exclusive input mode.
-    */
-    bool InExclusiveInputMode();
-
     //! Set the rendering surface for the current rendering.
     /*!
         This function is used to restore the rendering surface according to the system state. This is necessary after using a custom frame buffer object.
@@ -404,6 +414,8 @@ namespace nux
 #endif
 
   private:
+    typedef std::list<WeakBaseWindowPtr> WindowList;
+
     //! Render the interface.
     void Draw(bool SizeConfigurationEvent, bool force_draw);
 
@@ -418,7 +430,9 @@ namespace nux
         @WindowList The list of top views.
         @draw_modal True if the top view that is modal is to be rendered.
     */
-    void RenderTopViews(bool force_draw, std::list< ObjectWeakPtr<BaseWindow> >& WindowList, bool draw_modal);
+    void RenderTopViews(bool force_draw, WindowList&, bool draw_modal);
+
+    void PresentAnyReadyWindows();
 
     //! Render the content of a top view.
     void RenderTopViewContent(BaseWindow* window, bool force_draw);
@@ -436,11 +450,6 @@ namespace nux
     */
     void PresentBufferToScreen(ObjectPtr<IOpenGLBaseTexture> HWTexture, int x, int y, bool RenderToMainTexture, bool BluredBackground = false, float opacity=1.0f, bool premultiply = false);
 
-    /*!
-        Set the main color render target as the texture to draw into.
-    */
-    void SetMainColorRT();
-
     //! Push a floating view just above another floating view.
     /*!
         Note that only the top_floating_view is moving. The overall position of the reference view is not changing. 
@@ -455,19 +464,6 @@ namespace nux
     //! Push a floating view at the bottom of the stack.
     void PushToBack(BaseWindow* bottom_floating_view);
 
-    /*!
-        Returns the BaseWindow that is at the top of the BaseWindow stack, excluding the BaseWindow that is
-        chosen to be always on to.
-        \sa m_SelectedWindow. \sa SetAlwaysOnFrontWindow
-    */
-    BaseWindow* GetSelectedWindow();
-
-    
-    BaseWindow* GetFocusAreaWindow()
-    {
-      return m_FocusAreaWindow.GetPointer();
-    }
-
     //! Set the top view that is about to be processed(event or rendering).
     /*!
         Before event processing or rendering, this should be called to set the ViewWindow that is about 
@@ -480,16 +476,6 @@ namespace nux
 
     private:
 
-    void SetFocusAreaWindow(BaseWindow* window)
-    {
-      m_FocusAreaWindow = window;
-    }
-
-    void SetCurrentEvent(Event* event)
-    {
-      m_CurrentEvent = event;
-    }
-
     void EnsureAlwaysOnFrontWindow();
 
     void FormatRenderTargets(int width, int height);
@@ -512,58 +498,13 @@ namespace nux
     ObjectPtr<IOpenGLBaseTexture> m_MainDepthRT;
 
     WeakBaseWindowPtr m_CurrentWindow;    //!< BaseWindow where event processing or rendering is happening.
-    WeakBaseWindowPtr m_FocusAreaWindow;  //!< The BaseWindow that contains the _mouse_focus_area.
     WeakBaseWindowPtr m_MenuWindow;       //!< The BaseWindow that owns the menu being displayed;
-    Event* m_CurrentEvent; 
-
-    InputArea* _mouse_over_area;      //!< The base area that has the mouse directly over itself.
-    InputArea* _previous_mouse_over_area;
 
     void SetDnDArea(InputArea* area);
 
     // DnD support
     InputArea* _dnd_area;   //!< the area where the mouse is located during a DND action.
 
-    //! Set the exclusive input area according to _pending_exclusive_input_mode_action.
-    /*!
-        Following the event processing cycle, it is necessary to setup the exclusive input area is _pending_exclusive_input_mode_action is true.
-        The exclusive input area status always takes effect after the event processing cycle.
-    */
-    void ExecPendingExclusiveInputAreaAction();
-
-    //! Get the input area that has the exclusivity on events.
-    /*!
-        @return The input area that has the exclusivity on all events.
-    */
-    InputArea* GetExclusiveInputArea();
-
-    /*!
-        The exclusive input area gets all events without exception(greedy). The exclusive input area may decide to pass events 
-        down to other areas. If it does, the following restrictions apply:
-          - The other input area cannot have the mouse focus.
-          - They cannot have the keyboard focus.
-          - No synthetic events: 
-            * mouse click
-            * mouse drag
-          - Only atomic events:
-            * mouse down
-            * mouse up
-            * mouse move
-            * mouse enter/leave
-    */
-    InputArea* _exclusive_input_area;
-
-    /*!
-        \a _exclusive_input_area is true when there is an active greedy input area.
-    */
-    bool _in_exclusive_input_mode;
-
-    /*!
-        The exclusive input mode starts after after events have been processed inside ProcessEvent().
-        This flags signals that some action are required to enable/disable the exclusive input mode.
-    */
-    bool _pending_exclusive_input_mode_action;
-
     //! True while events are being processed inside ProcessEvent().
     bool inside_event_cycle_;
 
@@ -576,49 +517,39 @@ namespace nux
     Geometry    _tooltip_geometry;              //!< The geometry of the entire tooltip It includes the decoration surrounding the text such as round corners.
     Geometry    _tooltip_mainwindow_geometry;   //!< Same as _tooltip_geometry but based on the entire physical window of the application.
     Geometry    _tooltip_text_geometry;         //!< The geometry of the text area of the tooltip.
-    Point _event_root;
 
     bool on_menu_closure_continue_with_event_;
     AbstractPaintLayer* m_Background;
 
-    typedef std::list<WeakBaseWindowPtr> WindowList;
     WindowList _view_window_list;
     WindowList _modal_view_window_list;
     WeakBaseWindowPtr _always_on_front_window;  //!< Floating view that always remains on top.
 
+#if !defined(NUX_MINIMAL)
     std::list<MenuPage* >* _menu_chain;
-
-    /*!
-        The BaseWindow where the last mouse down event happened.
-        This BaseWindow will be raised to the top of the stack.
-        \sa GetSelectedWindow.
-    */
-    WeakBaseWindowPtr m_SelectedWindow;
+#endif
 
     std::map<BaseWindow*, struct RenderTargetTextures> _window_to_texture_map;
 
-    WeakBaseWindowPtr m_ModalWindow;
-    Point m_MouseLastPos;
-    Point m_MouseCurrentPos;
-
-    bool m_PopupRemoved;
     bool m_MenuRemoved;
-    bool m_MouseUp;
-    bool m_MouseDown;
 
     // Window Geometry
     int m_Width;
     int m_Height;
 
-    NString m_TooltipText;
+    std::string m_TooltipText;
     InputArea* m_TooltipArea;
     int m_TooltipX;
     int m_TooltipY;
 
     //! The fbo to restore after Nux rendering in embedded mode.
-    unsigned int reference_fbo_;
+    unsigned int draw_reference_fbo_;
+    unsigned int read_reference_fbo_;
     Geometry reference_fbo_geometry_;
 
+    //! True if the platform has support for depth textures.
+    bool platform_support_for_depth_texture_;
+
     //! Pointer grab stack.
     /*!
         The head of the list is the top of the stack.
@@ -635,6 +566,14 @@ namespace nux
     */
     std::list<InputArea*> keyboard_grab_stack_;
 
+    //! List of views that will get checked for the mouse_near signal
+    /*!
+        A list of views that will be checked if
+        \near the mouse. Must add views to this 
+        \list to be checked.
+    */
+    std::list<InputAreaProximity*> area_proximities_;
+
   private:
     WindowThread* window_thread_; //!< The WindowThread to which this object belongs.
 
@@ -642,6 +581,9 @@ namespace nux
     std::unique_ptr<GestureBroker> gesture_broker_;
 #endif
 
+    WindowList* currently_rendering_windows_;
+    Geometry* current_global_clip_rect_;
+
     //! Perform some action before destruction.
     /*!
         Perform some action before destruction. This function should only be 
