@@ -19,6 +19,8 @@
  *
  */
 
+#include <functional>
+
 #include "Nux.h"
 #include "Layout.h"
 #include "NuxCore/Logger.h"
@@ -30,13 +32,11 @@
 #include "FloatingWindow.h"
 
 #include "WindowThread.h"
+#include "MainLoopGLib.h"
 
 namespace nux
 {
-namespace
-{
-logging::Logger logger("nux.windows.thread");
-}
+DECLARE_LOGGER(logger, "nux.windows.thread");
 
   TimerFunctor *m_ScrollTimerFunctor;
   TimerHandle m_ScrollTimerHandler;
@@ -52,6 +52,7 @@ logging::Logger logger("nux.windows.thread");
 
   WindowThread::WindowThread(const char *WindowTitle, int width, int height, AbstractThread *Parent, bool Modal)
     : AbstractThread(Parent)
+    , foreign_frame_frozen_(false)
     , window_initial_width_(width)
     , window_initial_height_(height)
     , window_title_(WindowTitle)
@@ -60,6 +61,9 @@ logging::Logger logger("nux.windows.thread");
     , embedded_window_(false)
     , window_size_configuration_event_(false)
     , force_rendering_(false)
+#if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
+    , external_glib_sources_(new ExternalGLibSources)
+#endif
 #ifdef NUX_GESTURES_SUPPORT
     , geis_adapter_(new GeisAdapter)
 #endif
@@ -86,11 +90,12 @@ logging::Logger logger("nux.windows.thread");
     _draw_requested_to_host_wm       = false;
     first_pass_        = true;
 
+#if !defined(NUX_MINIMAL)
     _Timelines = new std::list<Timeline*> ();
-    GTimeVal time_val;
-    g_get_current_time(&time_val);
-    last_timeline_frame_time_sec_ = time_val.tv_sec;
-    last_timeline_frame_time_usec_ = time_val.tv_usec;
+    gint64 micro_secs = g_get_real_time();
+    last_timeline_frame_time_sec_ = micro_secs / 1000000;
+    last_timeline_frame_time_usec_ = micro_secs % 1000000;
+#endif
     _MasterClock = NULL;
 
 #if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
@@ -98,7 +103,7 @@ logging::Logger logger("nux.windows.thread");
     main_loop_glib_context_   = 0;
 #endif
 
-#if defined(NUX_OS_LINUX)
+#if defined(USE_X11)
     x11display_ = NULL;
     ownx11display_ = false;
 #endif
@@ -113,20 +118,23 @@ logging::Logger logger("nux.windows.thread");
   WindowThread::~WindowThread()
   {
 #if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
+    xim_controller_.reset();
     CleanupGlibLoop();
 #endif
 
     ThreadDtor();
+#if !defined(NUX_MINIMAL)
     std::list<Timeline*>::iterator li;
     for (li=_Timelines->begin(); li!=_Timelines->end(); ++li)
     {
       (*li)->UnReference();
     }
-    
     delete _Timelines;
+#endif
+
     delete async_wake_up_signal_;
 
-#if defined(NUX_OS_LINUX)
+#if defined(USE_X11)
     if (x11display_ && ownx11display_)
     {
       XCloseDisplay(x11display_);
@@ -159,12 +167,12 @@ logging::Logger logger("nux.windows.thread");
     return handle;
   }
 
-  void WindowThread::AsyncWakeUpCallback(void* data)
+  void WindowThread::AsyncWakeUpCallback(void* /* data */)
   {
     this->GetTimerHandler().RemoveTimerHandler(async_wake_up_timer_handle_);
     _pending_wake_up_timer = false;
   }
-  
+
   void WindowThread::ProcessDraw(GraphicsEngine &graphics_engine, bool force_draw)
   {
     if (main_layout_)
@@ -188,7 +196,7 @@ logging::Logger logger("nux.windows.thread");
   {
     _draw_requested_to_host_wm = true;
     RedrawRequested.emit();
-    
+
     if (!IsEmbeddedWindow())
     {
       // If the system is not in embedded mode and an asynchronous request for a Draw is made,
@@ -380,6 +388,7 @@ logging::Logger logger("nux.windows.thread");
       StopLayoutCycle();
   }
 
+#if !defined(NUX_MINIMAL)
   void WindowThread::AddTimeline(Timeline *timeline)
   {
     _Timelines->push_back(timeline);
@@ -390,13 +399,14 @@ logging::Logger logger("nux.windows.thread");
   void WindowThread::RemoveTimeline(Timeline *timeline)
   {
     _Timelines->remove(timeline);
-    if (_Timelines->size() == 0)
+    if (_Timelines->empty())
     {
       StopMasterClock();
     }
   }
+#endif
 
-  int WindowThread::Run(void *ptr)
+  int WindowThread::Run(void * /* ptr */)
   {
     if (GetWindowThread() != this)
     {
@@ -410,6 +420,10 @@ logging::Logger logger("nux.windows.thread");
       return 1;
     }
 
+    // Setup the main loop first, so that user_init_func can add new sources
+    // before running it
+    SetupMainLoop();
+
     if (user_init_func_ && (m_WidgetInitialized == false))
     {
       (*user_init_func_) (this, initialization_data_);
@@ -419,12 +433,29 @@ logging::Logger logger("nux.windows.thread");
     return MainLoop();
   }
 
-  int WindowThread::MainLoop()
+  void WindowThread::SetupMainLoop()
   {
     if (IsEmbeddedWindow())
     {
       window_compositor_->FormatRenderTargets(graphics_display_->GetWindowWidth(), graphics_display_->GetWindowHeight());
       InitGlibLoop();
+    }
+    else
+    {
+#if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
+      InitGlibLoop();
+#endif
+    }
+
+    // Called the first time so we can initialize the size of the render targets
+    // At this stage, the size of the window is known.
+    window_compositor_->FormatRenderTargets(graphics_display_->GetWindowWidth(), graphics_display_->GetWindowHeight());
+  }
+
+  int WindowThread::MainLoop()
+  {
+    if (IsEmbeddedWindow())
+    {
       RunGlibLoop();
       return 0;
     }
@@ -432,16 +463,12 @@ logging::Logger logger("nux.windows.thread");
     {
       graphics_display_->ShowWindow();
     }
-    // Called the first time so we can initialize the size of the render targets
-    // At this stage, the size of the window is known.
-    window_compositor_->FormatRenderTargets(graphics_display_->GetWindowWidth(), graphics_display_->GetWindowHeight());
 
     while (GetThreadState() != THREADSTOP)
     {
       if (GetThreadState() == THREADRUNNING)
       {
 #if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
-        InitGlibLoop();
         RunGlibLoop();
 #else
         ExecutionLoop();
@@ -495,6 +522,24 @@ logging::Logger logger("nux.windows.thread");
 
   extern EventToNameStruct EventToName[];
 
+  Event WindowThread::GetNextEvent()
+  {
+    Event event;
+    graphics_display_->GetSystemEvent(&event);
+
+#if defined(NUX_OS_LINUX) && defined(USE_X11)
+    // Make sure the current xic is synced up with the current event window
+    if ((event.type == KeyPress || event.type == KeyRelease) &&
+         event.x11_window && xim_controller_->GetCurrentWindow() != event.x11_window)
+    {
+      xim_controller_->SetFocusedWindow(event.x11_window);
+      graphics_display_->SetCurrentXIC(xim_controller_->GetXIC());
+    }
+#endif
+
+    return event;
+  }
+
 #if (!defined(NUX_OS_LINUX) && !defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) || defined(NUX_DISABLE_GLIB_LOOP)
 #ifdef NUX_GESTURES_SUPPORT
   Event *WindowThread::FetchNextEvent()
@@ -555,12 +600,58 @@ logging::Logger logger("nux.windows.thread");
       graphics_display_->GetSystemEvent(&event);
       int result = DoProcessEvent(event);
 #endif
+
+#if defined(NUX_OS_LINUX)
+      // select on all of our external fds. We can't use poll () here because
+      // ExectionLoop is designed to be a busy-wait system. In reality we should
+      // probably just drop support for this codepath.
+      //
+      // See https://bugs.launchpad.net/nux/+bug/1111216
+
+      fd_set read_fds;
+
+      FD_ZERO(&read_fds);
+
+      for (std::list<ExternalFdData>::iterator it =
+             _external_fds.begin();
+           it != _external_fds.end();
+           ++it)
+      {
+        nuxAssertMsg(it->fd < FD_SETSIZE, "[nux::WindowThread::ExecutionLoop]"\
+                     " file descriptor overflow, aborting");
+        FD_SET(it->fd, &read_fds);
+      }
+
+      // Wait 10 us
+      struct timeval timeout;
+      timeout.tv_sec = 0;
+      timeout.tv_usec = 10;
+
+      int select_result = select(_external_fds.size(), &read_fds, NULL, NULL,
+                                 &timeout);
+
+      nuxAssertMsg(select_result != -1, strerror ("select()"));
+
+      // Dispatch any active external fds
+      for (std::list<ExternalFdData>::iterator it =
+             _external_fds.begin();
+           it != _external_fds.end();
+           ++it)
+      {
+        if (FD_ISSET(it->fd, &read_fds))
+          it->cb();
+      }
+
       if (result != 1)
         return result;
     }
 
     return 1;
   }
+#else
+  nuxAssertMsg(_external_fds.empty(), "[nux::WindowThread::ExecutionLoop]"\
+               " external fd support is not implemented on Windows");
+#endif // NUX_OS_LINUX
 #endif // GLIB loop or not
 
   unsigned int WindowThread::ProcessEvent(Event &event)
@@ -659,7 +750,7 @@ logging::Logger logger("nux.windows.thread");
       {
         ReconfigureLayout();
       }
-      else 
+      else
       {
         // Compute the layouts that have been queued.
         ComputeQueuedLayout();
@@ -764,7 +855,7 @@ logging::Logger logger("nux.windows.thread");
     return 1;
   }
 
-  unsigned int SpawnThread(NThread &thread)
+  unsigned int SpawnThread(NThread & /* thread */)
   {
     return 0;
   }
@@ -839,7 +930,7 @@ logging::Logger logger("nux.windows.thread");
     }
   }
 
-  ThreadState WindowThread::Start(void *ptr)
+  ThreadState WindowThread::Start(void * /* ptr */)
   {
     if (!parent_)
     {
@@ -861,7 +952,7 @@ logging::Logger logger("nux.windows.thread");
     }
   }
 
-  ThreadState WindowThread::StartChildThread(AbstractThread *thread, bool Modal)
+  ThreadState WindowThread::StartChildThread(AbstractThread *thread, bool /* Modal */)
   {
     if (wait_for_modal_window_)
     {
@@ -940,19 +1031,20 @@ logging::Logger logger("nux.windows.thread");
     return state;
   }
 
-  bool WindowThread::ProcessTimelines(GTimeVal *frame_time)
+#if !defined(NUX_MINIMAL)
+  bool WindowThread::ProcessTimelines(gint64 micro_secs)
   {
     // go through our timelines and tick them
     // return true if we still have active timelines
 
     long msecs;
-    msecs = (frame_time->tv_sec - last_timeline_frame_time_sec_) * 1000 +
-            (frame_time->tv_usec - last_timeline_frame_time_usec_) / 1000;
+    msecs = (micro_secs / 1000000 - last_timeline_frame_time_sec_) * 1000 +
+            (micro_secs % 1000000 - last_timeline_frame_time_usec_) / 1000;
 
     if (msecs < 0)
     {
-      last_timeline_frame_time_sec_ = frame_time->tv_sec;
-      last_timeline_frame_time_usec_ = frame_time->tv_usec;
+      last_timeline_frame_time_sec_ = micro_secs / 1000000;
+      last_timeline_frame_time_usec_ = micro_secs % 1000000;
       return true;
     }
 
@@ -983,6 +1075,7 @@ logging::Logger logger("nux.windows.thread");
     // return if we have any timelines left
     return (_Timelines->size() != 0);
   }
+#endif
 
   void WindowThread::EnableMouseKeyboardInput()
   {
@@ -1074,6 +1167,8 @@ logging::Logger logger("nux.windows.thread");
     timer_manager_ = new TimerHandler(this);
     window_compositor_ = new WindowCompositor(this);
 
+    xim_controller_ = std::make_shared<XIMController>(graphics_display_->GetX11Display());
+
     SetThreadState(THREADRUNNING);
     thread_ctor_called_ = true;
     return true;
@@ -1088,9 +1183,7 @@ logging::Logger logger("nux.windows.thread");
       return true;
     }
 
-#if defined(NUX_OS_WINDOWS)
     SetWin32ThreadName(GetThreadId(), window_title_.c_str());
-#endif
 
     if (RegisterNuxThread(this) == FALSE)
     {
@@ -1141,6 +1234,7 @@ logging::Logger logger("nux.windows.thread");
 
     return true;
   }
+#elif defined(NO_X11)
 #elif defined(NUX_OS_LINUX)
 #ifdef NUX_OPENGLES_20
   bool WindowThread::ThreadCtor(Display *X11Display, Window X11Window, EGLContext OpenGLContext)
@@ -1172,7 +1266,7 @@ logging::Logger logger("nux.windows.thread");
       x11display_ = XOpenDisplay(NULL);
       ownx11display_ = true;
     }
-      
+
     graphics_display_ = gGLWindowManager.CreateFromForeignWindow(x11display_, X11Window, OpenGLContext);
 
     if (graphics_display_ == 0)
@@ -1191,6 +1285,8 @@ logging::Logger logger("nux.windows.thread");
     timer_manager_ = new TimerHandler(this);
     window_compositor_ = new WindowCompositor(this);
 
+    xim_controller_ = std::make_shared<XIMController>(graphics_display_->GetX11Display());
+
     SetThreadState(THREADRUNNING);
     thread_ctor_called_ = true;
 
@@ -1270,17 +1366,22 @@ logging::Logger logger("nux.windows.thread");
       return;
 
     if (window_compositor_)
+    {
       window_compositor_->SetBackgroundPaintLayer(background_layer);
+      if (main_layout_)
+      {
+        main_layout_->QueueDraw();
+      }
+    }
   }
-  
+
   void WindowThread::AddToDrawList(View *view)
   {
     Area *parent;
-    Geometry geo, pgeo;
-    
-    geo = view->GetAbsoluteGeometry();
+
+    Geometry const& geo = view->GetAbsoluteGeometry();
     parent = view->GetToplevel();
-    
+
     if (parent && (view != parent))
     {
 //       pgeo = parent->GetGeometry();
@@ -1301,28 +1402,69 @@ logging::Logger logger("nux.windows.thread");
       window->_child_need_redraw = true;
     }
 
-    m_dirty_areas.push_back(geo);
-  }
-  
-  void WindowThread::ClearDrawList()
-  {
-    m_dirty_areas.clear();
-  }
-  
-  std::vector<Geometry> WindowThread::GetDrawList()
-  {
-    return m_dirty_areas;
+    dirty_areas_.push_back(geo);
   }
 
-  bool WindowThread::IsEmbeddedWindow()
+  void WindowThread::ClearDrawList()
+  {
+    dirty_areas_.clear();
+  }
+
+  std::vector<Geometry> const& WindowThread::GetDrawList() const
+  {
+    return dirty_areas_;
+  }
+
+  bool WindowThread::AddToPresentationList(BaseWindow* bw, bool force)
+  {
+    if (!bw)
+      return false;
+
+    RequestRedraw();
+
+    bool force_or_not_frozen = (force || !foreign_frame_frozen_);
+    std::vector<WeakBaseWindowPtr>& target_list = force_or_not_frozen ? presentation_list_embedded_ :
+                                                                        presentation_list_embedded_next_frame_;
+
+    if (std::find(target_list.begin(), target_list.end(), bw) != target_list.end())
+      return force_or_not_frozen;
+
+    target_list.push_back(WeakBaseWindowPtr(bw));
+    return force_or_not_frozen;
+  }
+
+  std::vector<nux::Geometry> WindowThread::GetPresentationListGeometries() const
+  {
+    std::vector<nux::Geometry> presentation_geometries;
+    for (auto const& base_window : presentation_list_embedded_)
+    {
+      if (base_window.IsValid())
+      {
+        nux::Geometry const& abs_geom = base_window->GetAbsoluteGeometry();
+        nux::Geometry const& last_geom = base_window->LastPresentedGeometryInEmbeddedMode();
+        presentation_geometries.push_back(abs_geom);
+
+        if (abs_geom != last_geom)
+        {
+          if (!last_geom.IsNull())
+            presentation_geometries.push_back(last_geom);
+        }
+      }
+    }
+    return presentation_geometries;
+  }
+
+  bool WindowThread::IsEmbeddedWindow() const
   {
     return embedded_window_;
   }
 
 #if defined(NUX_OS_WINDOWS)
   bool WindowThread::ProcessForeignEvent(HWND hWnd, MSG msg, WPARAM wParam, LPARAM lParam, void *data)
-#elif defined(NUX_OS_LINUX)
-  bool WindowThread::ProcessForeignEvent(XEvent *xevent, void *data)
+#elif defined(USE_X11)
+  bool WindowThread::ProcessForeignEvent(XEvent *xevent, void * /* data */)
+#else
+  bool WindowThread::ProcessForeignEvent()
 #endif
   {
     if (graphics_display_->IsPauseThreadGraphicsRendering())
@@ -1334,7 +1476,7 @@ logging::Logger logger("nux.windows.thread");
     memset(&nux_event, 0, sizeof(Event));
 #if defined(NUX_OS_WINDOWS)
     graphics_display_->ProcessForeignWin32Event(hWnd, msg, wParam, lParam, &nux_event);
-#elif defined(NUX_OS_LINUX)
+#elif defined(USE_X11)
     graphics_display_->ProcessForeignX11Event(xevent, &nux_event);
 #endif
 
@@ -1391,7 +1533,7 @@ logging::Logger logger("nux.windows.thread");
       {
         ReconfigureLayout();
       }
-      else 
+      else
       {
         // Compute the layouts that have been queued.
         ComputeQueuedLayout();
@@ -1452,13 +1594,25 @@ logging::Logger logger("nux.windows.thread");
     return request_draw_cycle_to_host_wm;
   }
 
-  void WindowThread::RenderInterfaceFromForeignCmd(Geometry *clip)
+  void WindowThread::PresentWindowsIntersectingGeometryOnThisFrame(Geometry const& rect)
+  {
+    nuxAssertMsg(IsEmbeddedWindow(),
+                 "[WindowThread::PresentWindowIntersectingGeometryOnThisFrame] "
+                 "can only be called inside an embedded window");
+
+    window_compositor_->ForEachBaseWindow([&rect] (WeakBaseWindowPtr const& w) {
+      if (rect.IsIntersecting(w->GetAbsoluteGeometry()))
+        w->PresentInEmbeddedModeOnThisFrame(true);
+    });
+  }
+
+  void WindowThread::RenderInterfaceFromForeignCmd(Geometry const& clip)
   {
     nuxAssertMsg(IsEmbeddedWindow() == true, "[WindowThread::RenderInterfaceFromForeignCmd] You can only call RenderInterfaceFromForeignCmd if the window was created with CreateFromForeignWindow.");
 
     if (!IsEmbeddedWindow())
       return;
-    
+
     IOpenGLShaderProgram::SetShaderTracking(true);
 
     // Set Nux opengl states. The other plugin in compiz have changed the GPU opengl states.
@@ -1468,17 +1622,12 @@ logging::Logger logger("nux.windows.thread");
     GetWindowThread()->GetGraphicsEngine().SetOpenGLClippingRectangle(0, 0, GetWindowThread()->GetGraphicsEngine().GetWindowWidth(),
         GetWindowThread()->GetGraphicsEngine().GetWindowHeight());
 
-    if (graphics_display_->IsPauseThreadGraphicsRendering() == false)
+    if (!graphics_display_->IsPauseThreadGraphicsRendering())
     {
       ComputeQueuedLayout();
-      
-      if (clip)
-        GetWindowThread()->GetGraphicsEngine().SetGlobalClippingRectangle(Rect(clip->x, clip->y, clip->width, clip->height));
-        
+      GetWindowThread()->GetGraphicsEngine().SetGlobalClippingRectangle(clip);
       window_compositor_->Draw(window_size_configuration_event_, force_rendering_);
-      
-      if (clip)
-        GetWindowThread()->GetGraphicsEngine().DisableGlobalClippingRectangle();
+      GetWindowThread()->GetGraphicsEngine().DisableGlobalClippingRectangle();
       // When rendering in embedded mode, nux does not attempt to measure the frame rate...
 
       // Cleanup
@@ -1491,17 +1640,38 @@ logging::Logger logger("nux.windows.thread");
 
     CHECKGL( glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE));
 
-    graphics_display_->GetGpuDevice()->DeactivateFrameBuffer();
     IOpenGLShaderProgram::SetShaderTracking(false);
+  }
 
-    if (IsEmbeddedWindow() && window_compositor_->reference_fbo_)
+  void WindowThread::ForeignFrameEnded()
+  {
+    nuxAssertMsg(IsEmbeddedWindow(),
+                 "[WindowThread::ForeignFrameEnded] "
+                 "can only be called inside an embedded window");
+
+    window_compositor_->ForEachBaseWindow([] (WeakBaseWindowPtr const& w) {
+      w->MarkPresentedInEmbeddedMode();
+    });
+
+    presentation_list_embedded_.clear();
+
+    foreign_frame_frozen_ = false;
+
+    /* Move all the BaseWindows in presentation_list_embedded_next_frame_
+     * to presentation_list_embedded_ and mark them for presentation
+     */
+    for (auto const& win : presentation_list_embedded_next_frame_)
     {
-      // Restore the reference framebuffer
-      if (!window_compositor_->RestoreReferenceFramebuffer())
-      {
-        nuxDebugMsg("[WindowCompositor::RenderTopViews] Setting the Reference fbo has failed.");
-      }
+      if (win.IsValid())
+        win->PresentInEmbeddedModeOnThisFrame();
     }
+
+    presentation_list_embedded_next_frame_.clear();
+  }
+
+  void WindowThread::ForeignFrameCutoff()
+  {
+    foreign_frame_frozen_ = true;
   }
 
   int WindowThread::InstallEventInspector(EventInspector function, void* data)
@@ -1593,6 +1763,55 @@ logging::Logger logger("nux.windows.thread");
     return discard_event;
   }
 
+  bool
+  WindowThread::FindDataByFd(const WindowThread::ExternalFdData &data, int fd)
+  {
+    return data.fd == fd;
+  }
+
+  void WindowThread::WatchFdForEvents(int fd, const WindowThread::FdWatchCallback &cb)
+  {
+    ExternalFdData data;
+    data.fd = fd;
+    data.cb = cb;
+
+    _external_fds.push_back(data);
+#if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
+    AddFdToGLibLoop(fd,
+                    reinterpret_cast <gpointer> (&_external_fds.back()),
+                    WindowThread::ExternalSourceCallback);
+#endif
+  }
+
+  void WindowThread::UnwatchFd(int fd)
+  {
+    using namespace std::placeholders;
+
+    std::list<ExternalFdData>::iterator it =
+      std::find_if (_external_fds.begin(), _external_fds.end(),
+                    std::bind(FindDataByFd, _1, fd));
+
+    if (it != _external_fds.end())
+    {
+#if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
+      RemoveFdFromGLibLoop(&(*it));
+#endif
+      _external_fds.erase (it);
+    }
+  }
+#if defined(NUX_OS_LINUX) && defined(USE_X11)
+  void WindowThread::XICFocus(TextEntry* text_entry)
+  {
+    xim_controller_->FocusInXIC();
+    xim_controller_->SetCurrentTextEntry(text_entry);
+    graphics_display_->SetCurrentXIC(xim_controller_->GetXIC());
+  }
+
+  void WindowThread::XICUnFocus()
+  {
+    xim_controller_->FocusOutXIC();
+  }
+#endif
 
   GraphicsDisplay& WindowThread::GetGraphicsDisplay() const
   {
