@@ -29,9 +29,14 @@
 #include "GeisAdapter.h"
 #endif
 
+#if defined(NUX_OS_LINUX) && defined(USE_X11)
+#include "XIMController.h"
+#endif
+
 namespace nux
 {
 
+  class BaseWindow;
   class WindowThread;
   class Layout;
   class HLayout;
@@ -42,12 +47,16 @@ namespace nux
   class SystemThread;
   class UXTheme;
   class TimerHandler;
+#if !defined(NUX_MINIMAL)
   class Timeline;
+#endif
   class Event;
   class Area;
   struct ClientAreaDraw;
 
+
 #if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
+  class ExternalGLibSources;
   gboolean nux_event_dispatch(GSource *source, GSourceFunc callback, gpointer user_data);
   gboolean nux_timeout_dispatch(gpointer user_data);
 #endif
@@ -212,14 +221,27 @@ namespace nux
 
         @return True if embedded inside Compiz.
     */
-    bool IsEmbeddedWindow();
+    bool IsEmbeddedWindow() const;
 
 #if defined(NUX_OS_WINDOWS)
     bool ProcessForeignEvent(HWND hWnd, MSG msg, WPARAM wParam, LPARAM lParam, void *data);
-#elif defined(NUX_OS_LINUX)
+#elif defined(USE_X11)
     bool ProcessForeignEvent(XEvent *event, void *data);
+#else
+    bool ProcessForeignEvent();
 #endif
 
+    /*!
+        In embedded mode, allow presentation on any windows intersecting this
+        rect. The effect of this is culmulative for the frame, so it can be
+        called multiple times with many different rects until
+        RenderInterfaceFromForeignCmd is called.
+        \sa IsEmbeddedWindow
+
+        @param rect Region of the display to consider for presenting windows
+     */
+    void PresentWindowsIntersectingGeometryOnThisFrame(Geometry const& rect);
+
     /*!
         Render the interface. This command is send from the pluging when the window thread is embedded.
         The clip region matches the surface of one single monitor screen, or a region inside that screen.
@@ -227,16 +249,31 @@ namespace nux
 
         @param clip Region of the display to render.
     */
-    void RenderInterfaceFromForeignCmd(Geometry *clip);
+    void RenderInterfaceFromForeignCmd(Geometry const& clip);
 
+    /*!
+        Used to mark the end of the foreign frame. All calls to PresentInEmbeddedModeOnThisFrame
+        are now redirected to this upcoming frame where we will be called next.
+     */
+    void ForeignFrameEnded();
+
+    /*!
+        Used to mark the cutoff point where all calls to PresentInEmbeddedModeOnThisFrame
+        should be effective on the next frame, and not this one, because the parent context
+        has stopped tracking damage events for this frame
+     */
+    void ForeignFrameCutoff();
+
+#if !defined(NUX_MINIMAL)
     /*!
         Add a timeline to our window
     */
     void AddTimeline(Timeline* timeline);
     void RemoveTimeline(Timeline* timeline);
-    bool ProcessTimelines(GTimeVal *frame_time);
+    bool ProcessTimelines(gint64 micro_secs);
     long last_timeline_frame_time_sec_;
     long last_timeline_frame_time_usec_;
+#endif
 
     void StartMasterClock();
     void StopMasterClock();
@@ -311,11 +348,21 @@ namespace nux
 
     bool IsRedrawNeeded() const;
 
+    // DrawList - this is a maintained list of areas that will
+    // be completely redraw on the next frame
     void AddToDrawList(View *view);
-
     void ClearDrawList();
 
-    std::vector<Geometry> GetDrawList();
+    std::vector<Geometry> const& GetDrawList() const;
+
+    // PresentationList - this is a maintained list of areas that
+    // will be presented to the reference framebuffer or backbuffer
+    // in embedded mode on the next frame
+    bool AddToPresentationList(nux::BaseWindow*, bool force);
+
+    std::vector<Geometry> GetPresentationListGeometries() const;
+
+    Event GetNextEvent();
 
 #ifdef NUX_GESTURES_SUPPORT
     /*!
@@ -326,6 +373,15 @@ namespace nux
     GeisAdapter *GetGeisAdapter() const {return geis_adapter_.get();}
 #endif
 
+    typedef std::function<void()> FdWatchCallback;
+    void WatchFdForEvents(int fd, const FdWatchCallback &);
+    void UnwatchFd(int fd);
+
+#if defined(NUX_OS_LINUX) && defined(USE_X11)
+    void XICFocus(TextEntry* text_entry);
+    void XICUnFocus();
+#endif
+
   protected:
 
     /*!
@@ -357,7 +413,7 @@ namespace nux
         This function is called when Nux is embedded. \sa IsEmbeddedWindow.
     */
     virtual bool ThreadCtor(HWND WindowHandle, HDC WindowDCHandle, HGLRC OpenGLRenderingContext);
-#elif defined(NUX_OS_LINUX)
+#elif defined(USE_X11)
 #ifdef NUX_OPENGLES_20
     /*!
         Constructor-like function for the thread.
@@ -468,6 +524,8 @@ namespace nux
      */
     unsigned int DoProcessEvent(Event &event);
 
+    void SetupMainLoop();
+
     //! Execute the main loop of this thread.
     /*!
         Execute the main loop of this thread.
@@ -528,7 +586,24 @@ namespace nux
         This list contains the layout that need to be recomputed following the resizing of one of the sub element.
     */
     std::list<Area *> _queued_layout_list;
-    std::vector<Geometry> m_dirty_areas;
+    std::vector<Geometry> dirty_areas_;
+
+    typedef nux::ObjectWeakPtr<nux::BaseWindow> WeakBaseWindowPtr;
+
+    std::vector<WeakBaseWindowPtr> presentation_list_embedded_;
+
+    /*!
+        This list contains al lthe windows which will be presented on the next frame
+        (eg, after ForeignFrameEnded they are moved into m_presentation_list_embedded
+         and marked for presentation)
+     */
+    std::vector<WeakBaseWindowPtr> presentation_list_embedded_next_frame_;
+
+    /*! Whether or not the current frame is "frozen" because the host WM has stopped tracking
+        damage events. If so we should put all presentation requests on the next frame instead
+        of this one
+     */
+    bool foreign_frame_frozen_;
 
     //! This variable is true while we are computing the layout the starting from the outmost layout(the Main Layout);
     bool _inside_layout_cycle;
@@ -536,7 +611,9 @@ namespace nux
     //! Set to true to schedule a compute cycle on the main layout.
     bool queue_main_layout_;
 
+#if !defined(NUX_MINIMAL)
     std::list<Timeline*> *_Timelines;
+#endif
 
     bool first_pass_;                     //!< True when going through the ExecutionLoop for the first time.
     unsigned int window_initial_width_;   //!< Window height at startup.
@@ -601,6 +678,18 @@ namespace nux
     */
     std::map<int, EventInspectorStorage> _event_inspectors_map; //!< map of events inspectors
 
+    typedef struct _ExternalFdData
+    {
+      int             fd;
+      FdWatchCallback cb;
+    } ExternalFdData;
+
+    //! List of external sources. This might make more sense as a map,
+    //  but providing a struct provides us much nicer GLib integration
+    std::list<ExternalFdData> _external_fds;
+
+    static bool FindDataByFd(const WindowThread::ExternalFdData &data, int fd);
+
 #if (defined(NUX_OS_LINUX) || defined(NUX_USE_GLIB_LOOP_ON_WINDOWS)) && (!defined(NUX_DISABLE_GLIB_LOOP))
     GMainLoop *main_loop_glib_;
     GMainContext *main_loop_glib_context_;
@@ -608,12 +697,18 @@ namespace nux
     friend gboolean nux_timeout_dispatch(gpointer user_data);
     std::list<GSource*> child_window_list_;
 
+    std::unique_ptr<ExternalGLibSources> external_glib_sources_;
+
     void InitGlibLoop();
     void RunGlibLoop();
     void StopGLibLoop();
     void CleanupGlibLoop();
+    void AddFdToGLibLoop(int, gpointer, GSourceFunc);
+    void RemoveFdFromGLibLoop(gpointer);
     bool AddChildWindowGlibLoop(WindowThread* wnd_thread);
 
+    static gboolean ExternalSourceCallback(gpointer user_data);
+
     unsigned int AddGLibTimeout(unsigned int duration);
 #else // no GLIB loop
     Event input_event_;
@@ -625,6 +720,10 @@ namespace nux
     std::unique_ptr<GeisAdapter> geis_adapter_;
 #endif
 
+#if defined(NUX_OS_LINUX) && defined(USE_X11)
+    std::shared_ptr<XIMController> xim_controller_;
+#endif
+
     /*!
         Add a timeout and return the timeout index.
         This function is used internally by Nux.
@@ -692,16 +791,20 @@ namespace nux
     friend WindowThread *CreateFromForeignWindow(HWND WindowHandle, HDC WindowDCHandle, HGLRC OpenGLRenderingContext,
         ThreadUserInitFunc UserInitFunc,
         void *InitData);
-#elif defined(NUX_OS_LINUX)
-#ifdef NUX_OPENGLES_20
+#elif defined(USE_X11)
+#  ifdef NUX_OPENGLES_20
     friend WindowThread *CreateFromForeignWindow (Window X11Window, EGLContext OpenGLContext,
         ThreadUserInitFunc UserInitFunc,
         void *InitData);
-#else
+#  else
     friend WindowThread *CreateFromForeignWindow (Window X11Window, GLXContext OpenGLContext,
         ThreadUserInitFunc UserInitFunc,
         void *InitData);
-#endif
+#  endif
+#elif defined(NO_X11)
+    friend WindowThread *CreateFromForeignWindow (EGLDisplay disp, EGLContext OpenGLContext,
+        ThreadUserInitFunc UserInitFunc,
+        void *InitData);
 #endif
 
     friend SystemThread *CreateSystemThread(AbstractThread *Parent, ThreadUserInitFunc UserInitFunc, void *InitData);
