@@ -28,44 +28,36 @@
 namespace nux
 {
   Rect::Rect()
-  {
-    x = 0;
-    y = 0;
-    width = 0;
-    height = 0;
+    : x(0)
+    , y(0)
+    , width(0)
+    , height(0)
+  {}
 
+  Rect::Rect(int x_, int y_, int width_, int height_)
+    : x(x_)
+    , y(y_)
+    , width(std::max<int>(0, width_))
+    , height(std::max<int>(0, height_))
+  {}
+
+  Rect::Rect(const Rect &r)
+    : x(r.x)
+    , y(r.y)
+    , width(r.width)
+    , height(r.height)
+  {}
+
+  Rect::Rect(Rect &&r)
+    : Rect()
+  {
+    swap(*this, r);
   }
 
-  Rect::Rect (int x_, int y_, int width_, int height_)
+  Rect &Rect::operator = (Rect r)
   {
-    x = x_;
-    y = y_;
-    width = Max<int> (0, int (width_) );
-    height = Max<int> (0, int (height_) );
-  }
+    swap(*this, r);
 
-  Rect::~Rect()
-  {
-
-  }
-
-  Rect::Rect (const Rect &r)
-  {
-    x = r.x;
-    y = r.y;
-    width = r.width;
-    height = r.height;
-  }
-
-  Rect &Rect::operator = (const Rect &r)
-  {
-    if (&r == this)
-      return *this;
-
-    x = r.x;
-    y = r.y;
-    width = r.width;
-    height = r.height;
     return *this;
   }
 
@@ -132,23 +124,26 @@ namespace nux
              (y <= y_) && (y + height > y_) );
   }
 
+  bool Rect::IsIntersecting(const Rect &r) const
+  {
+    return ! ((r.x > x + width) ||
+              (r.x + r.width < x) ||
+              (r.y > y + height) ||
+              (r.y + r.height < y));
+  }
+
   Rect Rect::Intersect (const Rect &r) const
   {
     // Get the corner points.
 
-    bool intersect = ! ((r.x > x + width) ||
-                      (r.x + r.width < x) ||
-                      (r.y > y + height) ||
-                      (r.y + r.height < y));
-
-    if (intersect)
+    if (IsIntersecting(r))
     {
       const Point &ul1 = Point (x, y);
       const Point &ul2 = Point (r.x, r.y);
-      int xx = Max<int> (ul1.x, ul2.x);
-      int yy = Max<int> (ul1.y, ul2.y);
-      int ww = Min<int> (ul1.x + width,  ul2.x + r.width) - xx;
-      int hh = Min<int> (ul1.y + height, ul2.y + r.height) - yy;
+      int xx = std::max<int>(ul1.x, ul2.x);
+      int yy = std::max<int>(ul1.y, ul2.y);
+      int ww = std::min<int>(ul1.x + width,  ul2.x + r.width) - xx;
+      int hh = std::min<int>(ul1.y + height, ul2.y + r.height) - yy;
 
       return Rect (xx, yy, ww, hh);
     }
@@ -209,5 +204,10 @@ namespace nux
                 lhs.height * scalar);
   }
 
+  std::ostream& operator<<(std::ostream &os, Rect const& rect)
+  {
+    return os << "Rect, x: " << rect.x << " y: " << rect.y << " width: " <<
+                 rect.width << " height: " << rect.height << std::endl;
+  }
 }
 
