@@ -540,6 +540,9 @@ namespace nux
       new_opengl_rendering_context,
       1, 0, false);
 
+    if (m_DeviceFactory->GetGpuInfo().Support_EXT_Framebuffer_Object())
+      m_DeviceFactory->GetFrameBufferObject()->SetupFrameBufferObject();
+
     if (new_opengl_rendering_context != 0)
     {
       opengl_rendering_context_ = new_opengl_rendering_context;
@@ -578,6 +581,9 @@ namespace nux
       device_context_,
       opengl_rendering_context_);
 
+    if (m_DeviceFactory->GetGpuInfo().Support_EXT_Framebuffer_Object())
+      m_DeviceFactory->GetFrameBufferObject()->SetupFrameBufferObject();
+
     m_GraphicsContext = new GraphicsEngine(*this);
 
     InitGlobalGrabWindow();
@@ -717,7 +723,7 @@ namespace nux
 
     if (!wglMakeCurrent(device_context_, glrc))
     {
-      NString error = inlGetSystemErrorMessage();
+      std::string error = inlGetSystemErrorMessage();
       DestroyOpenGLWindow();
       MessageBox(NULL, "Can't Activate The GL Rendering Context.", "ERROR", MB_OK | MB_ICONERROR);
     }
@@ -2332,7 +2338,7 @@ namespace nux
 
   bool GraphicsDisplay::IsWindowVisible()
   {
-    return(::IsWindowVisible(wnd_handle_) ? true : false);
+    return ::IsWindowVisible(wnd_handle_);
   }
 //---------------------------------------------------------------------------------------------------------
   void GraphicsDisplay::EnterMaximizeWindow()
