@@ -108,6 +108,7 @@ namespace nux
     , m_X11Screen(0)
     , m_X11Window(0)
     , m_X11VisualInfo(NULL)
+    , m_current_xic(NULL)
     , parent_window_(0)
     , m_GLCtx(NULL)
 #ifndef NUX_OPENGLES_20
@@ -172,9 +173,6 @@ namespace nux
     NUX_SAFE_DELETE( m_GraphicsContext );
     NUX_SAFE_DELETE( m_DeviceFactory );
 
-    // The XIM Controller needs to clean up before ~GraphicsDisplayX11
-    m_xim_controller.reset();
-
     if (m_CreatedFromForeignWindow == false)
     {
       DestroyOpenGLWindow();
@@ -258,16 +256,6 @@ namespace nux
   }
 #endif
 
-  void GraphicsDisplay::XICFocus()
-  {
-    m_xim_controller->FocusInXIC();
-  }
-
-  void GraphicsDisplay::XICUnFocus()
-  {
-    m_xim_controller->FocusOutXIC();
-  }
-
   // TODO: change windowWidth, windowHeight, to window_size;
   static NCriticalSection CreateOpenGLWindow_CriticalSection;
   bool GraphicsDisplay::CreateOpenGLWindow(const char* window_title,
@@ -659,16 +647,6 @@ namespace nux
       //XMapRaised(m_X11Display, m_X11Window);
     }
 
-    m_xim_controller = std::make_shared<XIMController>(m_X11Display);
-    m_xim_controller->SetFocusedWindow(m_X11Window);
-
-    if (m_xim_controller->IsXICValid())
-    {
-      long im_event_mask=0;
-      XGetICValues(m_xim_controller->GetXIC(), XNFilterEvents, &im_event_mask, NULL);
-      m_X11Attr.event_mask |= im_event_mask;
-    }
-
 #ifndef NUX_OPENGLES_20
     if (_has_glx_13)
     {
@@ -778,8 +756,6 @@ namespace nux
 
     gfx_interface_created_ = true;
 
-    m_xim_controller = std::make_shared<XIMController>(m_X11Display);
-
     // m_DeviceFactory = new GpuDevice(viewport_size_.GetWidth(), viewport_size_.GetHeight(), BITFMT_R8G8B8A8);
     m_DeviceFactory = new GpuDevice(viewport_size_.width, viewport_size_.height, BITFMT_R8G8B8A8,
         m_X11Display,
@@ -811,14 +787,9 @@ namespace nux
     return m_DeviceFactory;
   }
 
-  void GraphicsDisplay::SetFocusedWindowForXIMController(Window window)
+  void GraphicsDisplay::SetCurrentXIC(XIC xic)
   {
-    m_xim_controller->SetFocusedWindow(window);
-  }
-
-  void GraphicsDisplay::RemoveFocusedWindowForXIMController()
-  {
-    m_xim_controller->RemoveFocusedWindow();
+    m_current_xic = xic;
   }
 
   int GraphicsDisplay::GetGlXMajor() const
@@ -1229,7 +1200,7 @@ namespace nux
       {
         _mouse_state |= NUX_EVENT_MOUSEWHEEL;
         m_pEvent->type = NUX_MOUSE_WHEEL;
-        m_pEvent->wheel_delta = NUX_MOUSEWHEEL_DELTA;
+        m_pEvent->wheel_delta = (NUX_MOUSEWHEEL_DELTA ^ 2);
         return 1;
       }
 
@@ -1237,7 +1208,7 @@ namespace nux
       {
         _mouse_state |= NUX_EVENT_MOUSEWHEEL;
         m_pEvent->type = NUX_MOUSE_WHEEL;
-        m_pEvent->wheel_delta = -NUX_MOUSEWHEEL_DELTA;
+        m_pEvent->wheel_delta = -(NUX_MOUSEWHEEL_DELTA ^ 2);
         return 1;
       }
     }
@@ -1360,7 +1331,9 @@ namespace nux
       XNextEvent(m_X11Display, &xevent);
 
       if (XFilterEvent(&xevent, None) == True)
+      {
         return true;
+      }
 
       if (!_event_filters.empty())
       {
@@ -1681,7 +1654,6 @@ namespace nux
         m_pEvent->virtual_code = 0;
         //nuxDebugMsg("[GraphicsDisplay::ProcessXEvents]: FocusIn event.");
 
-        m_xim_controller->FocusInXIC();
         break;
       }
 
@@ -1698,7 +1670,6 @@ namespace nux
         m_pEvent->virtual_code = 0;
         //nuxDebugMsg("[GraphicsDisplay::ProcessXEvents]: FocusOut event.");
 
-        m_xim_controller->FocusOutXIC();
         break;
       }
 
@@ -1725,20 +1696,20 @@ namespace nux
             (keysym == NUX_VK_ESCAPE))
         {
           //temporary fix for TextEntry widget: filter some keys
-         skip = true;
+          skip = true;
         }
 
         if (!skip)
         {
           int num_char_stored = 0;
 
-          if (m_xim_controller->IsXICValid())
+          if (m_current_xic)
           {
             delete[] m_pEvent->dtext;
             m_pEvent->dtext = nullptr;
             Status status;
 
-            num_char_stored = XmbLookupString(m_xim_controller->GetXIC(), &xevent.xkey, nullptr,
+            num_char_stored = XmbLookupString(m_current_xic, &xevent.xkey, nullptr,
                                               0, (KeySym*) &m_pEvent->x11_keysym, &status);
 
             if (status == XLookupKeySym)
@@ -1749,7 +1720,7 @@ namespace nux
             {
               int buf_len = num_char_stored + 1;
               m_pEvent->dtext = new char[buf_len];
-              num_char_stored = XmbLookupString(m_xim_controller->GetXIC(), &xevent.xkey, m_pEvent->dtext,
+              num_char_stored = XmbLookupString(m_current_xic, &xevent.xkey, m_pEvent->dtext,
                                                 buf_len, (KeySym*) &m_pEvent->x11_keysym, nullptr);
 
               m_pEvent->dtext[num_char_stored] = 0;
