@@ -35,7 +35,6 @@
 /* keysym.h contains keysymbols which we use to resolv what keys that are being pressed */
 #include <X11/keysym.h>
 
-
 #include <X11/extensions/xf86vmode.h>
 #include <X11/extensions/Xinerama.h>
 
@@ -85,6 +84,8 @@ namespace nux
     Window      m_X11Window;
     XVisualInfo *m_X11VisualInfo;
 
+    XIC m_current_xic;
+
     int         parent_window_;
 #ifndef NUX_OPENGLES_20
     GLXContext  m_GLCtx;
@@ -284,6 +285,8 @@ namespace nux
 
     GpuDevice* GetGpuDevice() const;
 
+    void SetCurrentXIC(XIC xic);
+
     // Dialog
     /*bool StartOpenFileDialog(FileDialogOption& fdo);
     bool StartSaveFileDialog(FileDialogOption& fdo);
@@ -423,28 +426,28 @@ namespace nux
     }
 #endif
 
-    NString FindResourceLocation(const char *ResourceFileName, bool ErrorOnFail = false);
-    NString FindUITextureLocation(const char *ResourceFileName, bool ErrorOnFail = false);
-    NString FindShaderLocation(const char *ResourceFileName, bool ErrorOnFail = false);
-    NString FindFontLocation(const char *ResourceFileName, bool ErrorOnFail = false);
+    std::string FindResourceLocation(const char *ResourceFileName, bool ErrorOnFail = false);
+    std::string FindUITextureLocation(const char *ResourceFileName, bool ErrorOnFail = false);
+    std::string FindShaderLocation(const char *ResourceFileName, bool ErrorOnFail = false);
+    std::string FindFontLocation(const char *ResourceFileName, bool ErrorOnFail = false);
 
-    const std::vector<NString>& GetFontSearchPath() const
+    const std::vector<std::string>& GetFontSearchPath() const
     {
       return m_FontSearchPath;
     }
-    const std::vector<NString>& GetShaderSearchPath() const
+    const std::vector<std::string>& GetShaderSearchPath() const
     {
       return m_ShaderSearchPath;
     }
-    const std::vector<NString>& GetUITextureSearchPath() const
+    const std::vector<std::string>& GetUITextureSearchPath() const
     {
       return m_UITextureSearchPath;
     }
 
   private:
-    std::vector<NString> m_FontSearchPath;
-    std::vector<NString> m_ShaderSearchPath;
-    std::vector<NString> m_UITextureSearchPath;
+    std::vector<std::string> m_FontSearchPath;
+    std::vector<std::string> m_ShaderSearchPath;
+    std::vector<std::string> m_UITextureSearchPath;
     FilePath m_ResourcePathLocation;
 
     GraphicsDisplay();
