@@ -234,27 +234,27 @@ namespace nux
     return OGL_OK;
   }
 
-  void IOpenGLBaseTexture::GetSurfaceLevel(int Level, ObjectPtr<IOpenGLSurface>& surface)
+  void IOpenGLBaseTexture::GetSurfaceLevel(int /* Level */, ObjectPtr<IOpenGLSurface>& /* surface */)
   {
 
   }
 
-  ObjectPtr<IOpenGLSurface> IOpenGLBaseTexture::GetSurfaceLevel(int Level)
+  ObjectPtr<IOpenGLSurface> IOpenGLBaseTexture::GetSurfaceLevel(int /* Level */)
   {
     return ObjectPtr<IOpenGLSurface> (0);
   }
 
-  int IOpenGLBaseTexture::LockRect(int Level, SURFACE_LOCKED_RECT *pLockedRect, const SURFACE_RECT *pRect)
+  int IOpenGLBaseTexture::LockRect(int /* Level */, SURFACE_LOCKED_RECT * /* pLockedRect */, const SURFACE_RECT * /* pRect */)
   {
     return 0;
   }
 
-  int IOpenGLBaseTexture::UnlockRect(int Level)
+  int IOpenGLBaseTexture::UnlockRect(int /* Level */)
   {
     return 0;
   }
 
-  unsigned char* IOpenGLBaseTexture::GetSurfaceData(int level, int &width, int &height, int &stride)
+  unsigned char* IOpenGLBaseTexture::GetSurfaceData(int /* level */, int &width, int &height, int &stride)
   {
     // Make this call a pure virtual once it has been implemented for IOpenGLCubeTexture,
     // IOpenGLVolumeTexture and IOpenGLAnimatedTexture.
@@ -264,6 +264,62 @@ namespace nux
     return 0;
   }
 
+  void IOpenGLBaseTexture::Save(const char* filename)
+  {
+    GLuint tex_id = GetOpenGLID();
+    glBindTexture(GL_TEXTURE_2D, tex_id);
+
+    int width, height;
+
+#ifndef NUX_OPENGLES_20
+      glGetTexLevelParameteriv(GL_TEXTURE_2D, 0, GL_TEXTURE_WIDTH, &width);
+      glGetTexLevelParameteriv(GL_TEXTURE_2D, 0, GL_TEXTURE_HEIGHT, &height);
+#else
+      width = GetWidth();
+      height = GetHeight();
+#endif
+
+      if(!width || !height)
+        return;
+
+      uint32_t* pixels = new uint32_t[width * height];
+      uint32_t* tmp = pixels;
+
+#ifndef NUX_OPENGLES_20
+      glGetTexImage(GL_TEXTURE_2D, 0, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
+#else
+      GLuint fbo;
+      glGenFramebuffers(1, &fbo);
+      glBindFramebuffer(GL_FRAMEBUFFER, fbo);
+      glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0, GL_TEXTURE_2D, tex_id, 0);
+      glReadPixels(0, 0, width, height, GL_RGBA, GL_UNSIGNED_BYTE, pixels);
+      glBindFramebuffer(GL_FRAMEBUFFER, 0);
+      glDeleteFramebuffers(1, &fbo);
+#endif
+
+      FILE* fp;
+      if(!(fp = fopen(filename, "wb"))) {
+        fprintf(stderr, "Cannot open file: %s\n", filename);
+        return;
+      }
+
+      fprintf(fp, "P6\n%d %d\n255\n", width, height);
+
+      int sz = width * height;
+      for(int i=0; i<sz; i++) {
+        uint32_t pix = *tmp++;
+        int r = (pix >> 16) & 0xff;
+        int g = (pix >> 8) & 0xff;
+        int b = pix & 0xff;
+
+        fputc(r, fp);
+        fputc(g, fp);
+        fputc(b, fp);
+      }
+
+      fclose(fp);
+      delete [] pixels;
+  }
 
   int GetTextureSize(IOpenGLBaseTexture *pTexture)
   {
@@ -324,8 +380,6 @@ namespace nux
     GLint unpack_alignment = GPixelFormats[pTexture->_PixelFormat].RowMemoryAlignment;
     unsigned int halfUnpack = Log2(unpack_alignment);
 
-    unsigned int BytePerPixel = 0;
-
     pDesc->PixelFormat = pTexture->_PixelFormat;
 
     if ( /*pTexture->_Format  == GL_COMPRESSED_RGB_S3TC_DXT1_EXT ||*/
@@ -388,13 +442,13 @@ namespace nux
     }
     else
     {
-      pDesc->Width            = Max<unsigned int> (1, pTexture->_Width >> Level);
-      pDesc->Height           = Max<unsigned int> (1, pTexture->_Height >> Level);
-      pDesc->WidthInBlocks    = pDesc->Width;
-      pDesc->HeightInBlocks   = pDesc->Height;
-      BytePerPixel            = GPixelFormats[pTexture->_PixelFormat].BlockBytes;
-      pDesc->BitsPerPixel     = BytePerPixel * 8;
-      pDesc->BytesPerBlock    = BytePerPixel; // a block is a 1x1 pixel ie. 1 pixel.
+      pDesc->Width              = Max<unsigned int> (1, pTexture->_Width >> Level);
+      pDesc->Height             = Max<unsigned int> (1, pTexture->_Height >> Level);
+      pDesc->WidthInBlocks      = pDesc->Width;
+      pDesc->HeightInBlocks     = pDesc->Height;
+      unsigned int BytePerPixel = GPixelFormats[pTexture->_PixelFormat].BlockBytes;
+      pDesc->BitsPerPixel       = BytePerPixel * 8;
+      pDesc->BytesPerBlock      = BytePerPixel; // a block is a 1x1 pixel ie. 1 pixel.
       pDesc->RowPitch = (((pDesc->Width * BytePerPixel + (unpack_alignment - 1)) >> (halfUnpack)) << (halfUnpack));
       pDesc->SlicePitch = (((pDesc->Width * BytePerPixel + (unpack_alignment - 1)) >> (halfUnpack)) << (halfUnpack)) * pDesc->Height;
     }
