@@ -30,18 +30,18 @@ namespace nux
   class IOpenGLResource;
   class IOpenGLVertexBuffer: public IOpenGLResource
   {
-    NUX_DECLARE_OBJECT_TYPE (IOpenGLVertexBuffer, IOpenGLResource);
+    NUX_DECLARE_OBJECT_TYPE(IOpenGLVertexBuffer, IOpenGLResource);
 
   public:
     virtual ~IOpenGLVertexBuffer();
 
-    int Lock (
-      t_u32 OffsetToLock,
-      t_u32 SizeToLock,
+    int Lock(
+      unsigned int OffsetToLock,
+      unsigned int SizeToLock,
       void **ppbData);
     int Unlock();
 
-    int GetDescription (VERTEXBUFFER_DESC *desc) const
+    int GetDescription(VERTEXBUFFER_DESC *desc) const
     {
       desc->Usage = _Usage;
       desc->Size = _Length;
@@ -49,17 +49,17 @@ namespace nux
     }
 
     void BindVertexBuffer();
-    t_u32 GetSize();
+    unsigned int GetSize();
 
   private:
-    IOpenGLVertexBuffer (t_u32 Length, VBO_USAGE Usage, NUX_FILE_LINE_PROTO);
+    IOpenGLVertexBuffer(unsigned int Length, VBO_USAGE Usage, NUX_FILE_LINE_PROTO);
 
-    t_u32 _Length;
+    unsigned int _Length;
     VBO_USAGE _Usage;
 
     BYTE *_MemMap;
-    t_u32  _OffsetToLock;
-    t_u32  _SizeToLock;
+    unsigned int  _OffsetToLock;
+    unsigned int  _SizeToLock;
     friend class GpuDevice;
   };
 
