@@ -9,6 +9,7 @@
 
 #include "Nux/Nux.h"
 #include "Nux/BaseWindow.h"
+#include "Nux/InputAreaProximity.h"
 #include "Nux/HLayout.h"
 #include "Nux/VLayout.h"
 #include "Nux/ProgramFramework/TestView.h"
@@ -54,12 +55,12 @@ struct TestBaseWindow : public nux::BaseWindow
     ShowWindow(true);
   }
 
-  nux::Area* FindAreaUnderMouse(const nux::Point& mouse_position, nux::NuxEventType event_type)
+  nux::Area* FindAreaUnderMouse(const nux::Point& /* mouse_position */, nux::NuxEventType /* event_type */)
   {
     return input_area.GetPointer();
   }
 
-  Area* FindKeyFocusArea(unsigned int key_symbol, unsigned long x11_key_code, unsigned long special_keys_state)
+  Area* FindKeyFocusArea(unsigned int /* key_symbol */, unsigned long /* x11_key_code */, unsigned long /* special_keys_state */)
   {
     return input_area.GetPointer();
   }
@@ -71,12 +72,12 @@ struct TestHLayout : public nux::HLayout
 {
   TestHLayout() : input_area(new nux::InputArea()) {}
 
-  nux::Area* FindAreaUnderMouse(const nux::Point& mouse_position, nux::NuxEventType event_type)
+  nux::Area* FindAreaUnderMouse(const nux::Point& /* mouse_position */, nux::NuxEventType /* event_type */)
   {
     return input_area.GetPointer();
   }
 
-  Area* FindKeyFocusArea(unsigned int key_symbol, unsigned long x11_key_code, unsigned long special_keys_state)
+  Area* FindKeyFocusArea(unsigned int /* key_symbol */, unsigned long /* x11_key_code */, unsigned long /* special_keys_state */)
   {
     return input_area.GetPointer();
   }
@@ -126,10 +127,9 @@ struct TestWindowCompositor : public testing::Test
   }
 
   void GetAreaUnderMouse(const Point& mouse_position, NuxEventType event_type,
-                         ObjectWeakPtr<InputArea>& area,
-                         ObjectWeakPtr<BaseWindow>& window)
+                         ObjectWeakPtr<InputArea>& area)
   {
-    return nux::GetWindowCompositor().GetAreaUnderMouse(mouse_position, event_type, area, window);
+    return nux::GetWindowCompositor().FindAreaUnderMouse(mouse_position, event_type, area);
   }
 
   void FindKeyFocusArea(NuxEventType event_type, unsigned int key_symbol,
@@ -145,82 +145,147 @@ struct TestWindowCompositor : public testing::Test
 
 namespace
 {
+  typedef void (*NGLGenFramebuffers)(GLsizei, GLuint *);
+  typedef void (*NGLGenRenderbuffers)(GLsizei, GLuint *);
+  typedef void (*NGLBindFramebuffer)(GLenum, GLuint);
+  typedef void (*NGLBindRenderbuffer)(GLenum, GLuint);
+  typedef void (*NGLRenderbufferStorage)(GLenum, GLenum, GLsizei, GLsizei);
+  typedef void (*NGLFramebufferRenderbuffer)(GLenum, GLenum, GLenum, GLuint);
+  typedef void (*NGLDeleteFramebuffers)(GLsizei, const GLuint *);
+  typedef void (*NGLDeleteRenderbuffers)(GLsizei, const GLuint *);
+
+  #ifdef NUX_OPENGLES_20
+  GLuint NGL_RENDERBUFFER = GL_RENDERBUFFER;
+  /* No separate draw or read targets on OpenGL|ES */
+  GLuint NGL_DRAW_FRAMEBUFFER = GL_FRAMEBUFFER;
+  GLuint NGL_READ_FRAMEBUFFER = GL_FRAMEBUFFER;
+  GLuint NGL_DRAW_FRAMEBUFFER_BINDING = GL_FRAMEBUFFER_BINDING;
+  GLuint NGL_READ_FRAMEBUFFER_BINDING = GL_FRAMEBUFFER_BINDING;
+  GLuint NGL_COLOR_ATTACHMENT0 = GL_COLOR_ATTACHMENT0;
+  GLuint NGL_RGBA_STORAGE = GL_RGBA4;
+  #else
+  GLuint NGL_RENDERBUFFER = GL_RENDERBUFFER_EXT;
+  GLuint NGL_DRAW_FRAMEBUFFER = GL_DRAW_FRAMEBUFFER_EXT;
+  GLuint NGL_READ_FRAMEBUFFER = GL_READ_FRAMEBUFFER_EXT;
+  GLuint NGL_DRAW_FRAMEBUFFER_BINDING = GL_DRAW_FRAMEBUFFER_BINDING_EXT;
+  GLuint NGL_READ_FRAMEBUFFER_BINDING = GL_DRAW_FRAMEBUFFER_BINDING_EXT;
+  GLuint NGL_COLOR_ATTACHMENT0 = GL_COLOR_ATTACHMENT0_EXT;
+  GLuint NGL_RGBA_STORAGE = GL_RGBA8_EXT;
+  #endif
+
   class ReferenceFramebuffer
   {
     public:
 
       ReferenceFramebuffer ()
       {
-        glGenFramebuffersEXT (1, &fboName);
-        glGenRenderbuffersEXT (1, &rbName);
+        #ifdef NUX_OPENGLES_20
+        nglGenFramebuffers = &glGenFramebuffers;
+        nglGenRenderbuffers = &glGenRenderbuffers;
+        nglBindRenderbuffer = &glBindRenderbuffer;
+        nglBindFramebuffer = &glBindFramebuffer;
+        nglRenderbufferStorage = &glRenderbufferStorage;
+        nglFramebufferRenderbuffer = &glFramebufferRenderbuffer;
+        nglDeleteRenderbuffers = &glDeleteRenderbuffers;
+        nglDeleteFramebuffers = &glDeleteFramebuffers;
+        #else
+        nglGenFramebuffers = glGenFramebuffersEXT;
+        nglGenRenderbuffers = glGenRenderbuffersEXT;
+        nglBindRenderbuffer = glBindRenderbufferEXT;
+        nglBindFramebuffer = glBindFramebufferEXT;
+        nglRenderbufferStorage = glRenderbufferStorageEXT;
+        nglFramebufferRenderbuffer = glFramebufferRenderbufferEXT;
+        nglDeleteRenderbuffers = glDeleteRenderbuffersEXT;
+        nglDeleteFramebuffers = glDeleteFramebuffersEXT;
+        #endif
 
-        glBindRenderbufferEXT (GL_RENDERBUFFER_EXT, rbName);
-        glRenderbufferStorageEXT (GL_RENDERBUFFER_EXT, GL_RGBA8_EXT, 300, 200);
-        glBindFramebufferEXT (GL_FRAMEBUFFER_EXT, fboName);
-        glFramebufferRenderbufferEXT (GL_FRAMEBUFFER_EXT, GL_COLOR_ATTACHMENT0_EXT, GL_RENDERBUFFER_EXT, rbName);
+        nglGenFramebuffers(1, &fboName);
+        nglGenRenderbuffers(1, &rbName);
+
+        nglBindRenderbuffer(NGL_RENDERBUFFER, rbName);
+        nglRenderbufferStorage(NGL_RENDERBUFFER, NGL_RGBA_STORAGE, 300, 200);
+        nglBindFramebuffer(NGL_DRAW_FRAMEBUFFER, fboName);
+        nglBindFramebuffer(NGL_READ_FRAMEBUFFER, fboName);
+        nglFramebufferRenderbuffer(NGL_DRAW_FRAMEBUFFER, NGL_COLOR_ATTACHMENT0, NGL_RENDERBUFFER, rbName);
       }
 
       ~ReferenceFramebuffer ()
       {
-        glBindFramebufferEXT (GL_FRAMEBUFFER_EXT, 0);
-        glDeleteRenderbuffers (1, &rbName);
-        glDeleteRenderbuffers (1, &fboName);
+        nglBindFramebuffer(NGL_DRAW_FRAMEBUFFER, 0);
+        nglBindFramebuffer(NGL_READ_FRAMEBUFFER, 0);
+        nglDeleteRenderbuffers(1, &rbName);
+        nglDeleteFramebuffers(1, &fboName);
       }
 
-    GLuint fboName, rbName;
+      GLuint fboName, rbName;
+
+      /* Each instance of the class needs to keep its own
+       * copy of the extension functions as glewInit () needs
+       * to be called in the desktop case before they are available */
+
+      NGLGenFramebuffers nglGenFramebuffers;
+      NGLGenRenderbuffers nglGenRenderbuffers;
+      NGLBindRenderbuffer nglBindRenderbuffer;
+      NGLBindFramebuffer nglBindFramebuffer;
+      NGLRenderbufferStorage nglRenderbufferStorage;
+      NGLFramebufferRenderbuffer nglFramebufferRenderbuffer;
+      NGLDeleteRenderbuffers nglDeleteRenderbuffers;
+      NGLDeleteFramebuffers nglDeleteFramebuffers; 
   };
 }
+
 TEST_F(TestWindowCompositor, TestRestoreReferenceFramebufferDirect)
 {
   ReferenceFramebuffer reference;
-  GLint  fbBinding;
+  GLint  dfbBinding, rfbBinding;
 
-  glGetIntegerv (GL_FRAMEBUFFER_BINDING_EXT, &fbBinding);
+  glGetIntegerv(NGL_DRAW_FRAMEBUFFER_BINDING, &dfbBinding);
+  glGetIntegerv(NGL_READ_FRAMEBUFFER_BINDING, &rfbBinding);
 
-  ASSERT_EQ (fbBinding, reference.fboName);
+  ASSERT_EQ (dfbBinding, reference.fboName);
 
-  wnd_thread->GetWindowCompositor().SetReferenceFramebuffer(fbBinding, nux::Geometry (0, 0, 300, 200));
+  wnd_thread->GetWindowCompositor().SetReferenceFramebuffer(dfbBinding, rfbBinding, nux::Geometry (0, 0, 300, 200));
 
   ASSERT_TRUE (wnd_thread->GetWindowCompositor().RestoreReferenceFramebuffer());
-  glGetIntegerv (GL_FRAMEBUFFER_BINDING_EXT, &fbBinding);
-  ASSERT_EQ (fbBinding, reference.fboName);
+  glGetIntegerv(NGL_DRAW_FRAMEBUFFER_BINDING, &dfbBinding);
+  glGetIntegerv(NGL_READ_FRAMEBUFFER_BINDING, &rfbBinding);
+  ASSERT_EQ (dfbBinding, reference.fboName);
+  ASSERT_EQ (rfbBinding, reference.fboName);
 }
 
 TEST_F(TestWindowCompositor, TestRestoreReferenceFramebufferThroughRestoreMain)
 {
   ReferenceFramebuffer reference;
-  GLint  fbBinding;
+  GLint  dfbBinding, rfbBinding;
 
-  glGetIntegerv (GL_FRAMEBUFFER_BINDING_EXT, &fbBinding);
+  glGetIntegerv(NGL_DRAW_FRAMEBUFFER_BINDING, &dfbBinding);
+  glGetIntegerv(NGL_READ_FRAMEBUFFER_BINDING, &rfbBinding);
 
-  ASSERT_EQ (fbBinding, reference.fboName);
+  ASSERT_EQ(dfbBinding, reference.fboName);
 
-  wnd_thread->GetWindowCompositor().SetReferenceFramebuffer(fbBinding, nux::Geometry (0, 0, 300, 200));
+  wnd_thread->GetWindowCompositor().SetReferenceFramebuffer(dfbBinding, rfbBinding, nux::Geometry (0, 0, 300, 200));
   wnd_thread->GetWindowCompositor().RestoreMainFramebuffer();
-  glGetIntegerv (GL_FRAMEBUFFER_BINDING_EXT, &fbBinding);
-  ASSERT_EQ (fbBinding, reference.fboName);
-}
-
-TEST_F(TestWindowCompositor, TestNoRestoreReferenceFramebufferDirectIfNoReferenceFramebuffer)
-{
-  GLint fbBinding;
-  ASSERT_FALSE (wnd_thread->GetWindowCompositor().RestoreReferenceFramebuffer());
-  glGetIntegerv (GL_FRAMEBUFFER_BINDING_EXT, &fbBinding);
-  ASSERT_EQ (fbBinding, 0);
+  glGetIntegerv(NGL_DRAW_FRAMEBUFFER_BINDING, &dfbBinding);
+  glGetIntegerv(NGL_READ_FRAMEBUFFER_BINDING, &rfbBinding);
+  ASSERT_EQ(dfbBinding, reference.fboName);
+  ASSERT_EQ(rfbBinding, reference.fboName);
 }
 
 TEST_F(TestWindowCompositor, TestRestoreBackbufferThroughRestoreMain)
 {
   ReferenceFramebuffer reference;
-  GLint  fbBinding;
+  GLint dfbBinding, rfbBinding;
 
-  glGetIntegerv (GL_FRAMEBUFFER_BINDING_EXT, &fbBinding);
+  glGetIntegerv(NGL_DRAW_FRAMEBUFFER_BINDING, &dfbBinding);
+  glGetIntegerv(NGL_READ_FRAMEBUFFER_BINDING, &rfbBinding);
 
-  ASSERT_EQ (fbBinding, reference.fboName);
+  ASSERT_EQ (dfbBinding, reference.fboName);
 
   wnd_thread->GetWindowCompositor().RestoreMainFramebuffer();
-  glGetIntegerv (GL_FRAMEBUFFER_BINDING_EXT, &fbBinding);
-  ASSERT_EQ (fbBinding, 0);
+  glGetIntegerv(NGL_DRAW_FRAMEBUFFER_BINDING, &dfbBinding);
+  glGetIntegerv(NGL_READ_FRAMEBUFFER_BINDING, &rfbBinding);
+  ASSERT_EQ(dfbBinding, 0);
+  ASSERT_EQ(rfbBinding, 0);
 }
 
 TEST_F(TestWindowCompositor, TestSetKeyFocusArea)
@@ -263,6 +328,15 @@ TEST_F(TestWindowCompositor, TestSetKeyFocusArea)
   }
 }
 
+TEST_F(TestWindowCompositor, TestInputAreaProximityNullValue)
+{
+  const int prox_size = nux::GetWindowCompositor().GetProximityListSize();
+  nux::InputAreaProximity* prox_area = new nux::InputAreaProximity(NULL, 10);
+
+  ASSERT_EQ(nux::GetWindowCompositor().GetProximityListSize(), prox_size);
+  delete prox_area;
+}
+
 #ifdef NUX_GESTURES_SUPPORT
 
 /*
@@ -550,32 +624,27 @@ TEST_F(TestWindowCompositor, MouseOwnerAreaAutomaticallyUnsets)
 TEST_F(TestWindowCompositor, GetAreaUnderMouse)
 {
   ObjectWeakPtr<InputArea> area;
-  ObjectWeakPtr<BaseWindow> window;
 
   TestBaseWindow* test_win = new TestBaseWindow();
 
-  GetAreaUnderMouse(Point(1, 2), NUX_MOUSE_MOVE, area, window);
+  GetAreaUnderMouse(Point(1, 2), NUX_MOUSE_MOVE, area);
 
   EXPECT_EQ(area.GetPointer(), test_win->input_area.GetPointer());
-  EXPECT_EQ(window.GetPointer(), test_win);
 
   test_win->UnReference();
   EXPECT_EQ(area.GetPointer(), nullptr);
-  EXPECT_EQ(window.GetPointer(), nullptr);
 }
 
 TEST_F(TestWindowCompositor, GetAreaUnderMouseFallback)
 {
   ObjectWeakPtr<InputArea> area;
-  ObjectWeakPtr<BaseWindow> window;
 
   TestHLayout* layout = new TestHLayout();
   wnd_thread->SetLayout(layout);
 
-  GetAreaUnderMouse(Point(1, 2), NUX_MOUSE_MOVE, area, window);
+  GetAreaUnderMouse(Point(1, 2), NUX_MOUSE_MOVE, area);
 
   EXPECT_EQ(area.GetPointer(), layout->input_area.GetPointer());
-  EXPECT_EQ(window.GetPointer(), nullptr);
 
   wnd_thread->SetLayout(nullptr);
   layout->UnReference();
@@ -617,6 +686,229 @@ TEST_F(TestWindowCompositor, GetFocusedAreaFallback)
   EXPECT_EQ(area.GetPointer(), nullptr);
 }
 
+class DraggedWindow : public nux::BaseWindow
+{
+ public:
+  DraggedWindow()
+  : mouse_drag_emission_count(0)
+  , mouse_drag_x(0)
+  , mouse_drag_y(0)
+  , mouse_drag_dx(0)
+  , mouse_drag_dy(0)
+  {}
+
+ protected:
+  virtual void EmitMouseDragSignal(int x, int y,
+      int dx, int dy,
+      unsigned long /*mouse_button_state*/,
+      unsigned long /*special_keys_state*/)
+  {
+    ++mouse_drag_emission_count;
+    mouse_drag_x = x;
+    mouse_drag_y = y;
+    mouse_drag_dx = dx;
+    mouse_drag_dy = dy;
+  }
+ public:
+  int mouse_drag_emission_count;
+  int mouse_drag_x;
+  int mouse_drag_y;
+  int mouse_drag_dx;
+  int mouse_drag_dy;
+};
+
+/*
+  Regression test for lp1057995
+ */
+TEST_F(TestWindowCompositor, MouseDrag)
+{
+  nux::Event event;
+
+  DraggedWindow *window = new DraggedWindow;
+  window->SetBaseXY(60, 70);
+  window->SetBaseWidth(200);
+  window->SetBaseHeight(200);
+  window->ShowWindow(true);
+
+  event.type = NUX_MOUSE_PRESSED;
+  event.x = 100;
+  event.y = 200;
+  nux::GetWindowCompositor().ProcessEvent(event);
+
+  event.type = NUX_MOUSE_MOVE;
+  event.x = 50;
+  event.y = 250;
+  nux::GetWindowCompositor().ProcessEvent(event);
+
+  ASSERT_EQ(1, window->mouse_drag_emission_count);
+
+  /* OBS: they're in local window coordinates */
+  ASSERT_EQ(50 - 60, window->mouse_drag_x); 
+  ASSERT_EQ(250 - 70, window->mouse_drag_y);
+  ASSERT_EQ(50 - 100, window->mouse_drag_dx);
+  ASSERT_EQ(250 - 200, window->mouse_drag_dy);
+
+  window->Dispose();
+}
+
+class TrackerWindow : public nux::BaseWindow
+{
+  public:
+    TrackerWindow()
+    : mouse_up_emission_count(0)
+    , mouse_drag_emission_count(0)
+    , mouse_drag_dx(0)
+    , mouse_drag_dy(0)
+    {}
+
+    virtual bool ChildMouseEvent(const nux::Event& event)
+    {
+      child_mouse_events_received.push_back(event);
+      return wants_mouse_ownership;
+    }
+    std::vector<nux::Event> child_mouse_events_received;
+    bool wants_mouse_ownership;
+
+  protected:
+    virtual void EmitMouseUpSignal(int x, int y,
+                                   unsigned long mouse_button_state,
+                                   unsigned long special_keys_state)
+    {
+      ++mouse_up_emission_count;
+    }
+
+    virtual void EmitMouseDragSignal(int x, int y,
+                                     int dx, int dy,
+                                     unsigned long mouse_button_state,
+                                     unsigned long special_keys_state)
+    {
+      ++mouse_drag_emission_count;
+      mouse_drag_dx = dx;
+      mouse_drag_dy = dy;
+    }
+  public:
+    int mouse_up_emission_count;
+    int mouse_drag_emission_count;
+    int mouse_drag_dx;
+    int mouse_drag_dy;
+};
+
+class TrackedArea : public nux::InputArea
+{
+  public:
+    TrackedArea()
+    : mouse_down_emission_count(0)
+    , mouse_up_emission_count(0)
+    , mouse_drag_emission_count(0)
+    , mouse_cancel_emission_count(0)
+    {}
+
+  protected:
+    virtual void EmitMouseDownSignal(int x, int y,
+                                     unsigned long mouse_button_state,
+                                     unsigned long special_keys_state)
+    {
+      ++mouse_down_emission_count;
+    }
+
+    virtual void EmitMouseUpSignal(int x, int y,
+                                   unsigned long mouse_button_state,
+                                   unsigned long special_keys_state)
+    {
+      ++mouse_up_emission_count;
+    }
+
+    virtual void EmitMouseDragSignal(int x, int y,
+                                     int dx, int dy,
+                                     unsigned long mouse_button_state,
+                                     unsigned long special_keys_state)
+    {
+      ++mouse_drag_emission_count;
+    }
+
+    virtual void EmitMouseCancelSignal()
+    {
+      ++mouse_cancel_emission_count;
+    }
+
+  public:
+    int mouse_down_emission_count;
+    int mouse_up_emission_count;
+    int mouse_drag_emission_count;
+    int mouse_cancel_emission_count;
+};
+
+TEST_F(TestWindowCompositor, TrackingChildMouseEvents)
+{
+  nux::WindowCompositor &wnd_compositor = wnd_thread->GetWindowCompositor();
+
+  TrackedArea *tracked_area = new TrackedArea;
+  tracked_area->SetGeometry(0, 0, 100, 1000);
+  tracked_area->SetMinimumSize(100, 1000);
+
+  nux::VLayout *layout = new VLayout(NUX_TRACKER_LOCATION);
+  layout->AddView(tracked_area, 1, eLeft, eFull);
+  layout->Set2DTranslation(0, -123, 0); // x, y, z
+
+  TrackerWindow *tracker_window = new TrackerWindow;
+  tracker_window->SetBaseXY(0, 0);
+  tracker_window->SetBaseWidth(100);
+  tracker_window->SetBaseHeight(100);
+  tracker_window->SetTrackChildMouseEvents(true);
+  tracker_window->SetLayout(layout);
+  tracker_window->ShowWindow(true);
+
+  // Mouse pressed goes both to child and tracker window
+  tracker_window->wants_mouse_ownership = false;
+  tracked_area->mouse_down_emission_count = 0;
+  nux::Event event;
+  event.type = NUX_MOUSE_PRESSED;
+  event.x = 50; // right in the center of tracker_window
+  event.y = 50;
+  wnd_compositor.ProcessEvent(event);
+  ASSERT_EQ(1, tracker_window->child_mouse_events_received.size());
+  ASSERT_EQ(1, tracked_area->mouse_down_emission_count);
+
+  // Mouse move goes both to child and tracker window, but tracker asks
+  // for mouse ownership. Therefore child also gets a mouse cancel.
+  tracker_window->child_mouse_events_received.clear();
+  tracker_window->wants_mouse_ownership = true;
+  tracked_area->mouse_drag_emission_count = 0;
+  tracked_area->mouse_cancel_emission_count = 0;
+  event.type = NUX_MOUSE_MOVE;
+  event.y = 60;
+  wnd_compositor.ProcessEvent(event);
+  ASSERT_EQ(1, tracker_window->child_mouse_events_received.size());
+  ASSERT_EQ(1, tracked_area->mouse_drag_emission_count);
+  ASSERT_EQ(1, tracked_area->mouse_cancel_emission_count);
+
+  // The second mouse move goes only to the window, but now as a regular
+  // mouse event since he's mouse owner now.
+  tracker_window->child_mouse_events_received.clear();
+  tracker_window->mouse_drag_emission_count = 0;
+  tracked_area->mouse_drag_emission_count = 0;
+  event.type = NUX_MOUSE_MOVE;
+  event.y = 70;
+  wnd_compositor.ProcessEvent(event);
+  ASSERT_EQ(0, tracker_window->child_mouse_events_received.size());
+  ASSERT_EQ(1, tracker_window->mouse_drag_emission_count);
+  ASSERT_EQ(0, tracked_area->mouse_drag_emission_count);
+  ASSERT_EQ(10, tracker_window->mouse_drag_dy);
+
+  // Mouse release goes only to the window, again as a regular
+  // mouse event.
+  tracker_window->child_mouse_events_received.clear();
+  tracker_window->mouse_up_emission_count = 0;
+  tracked_area->mouse_up_emission_count = 0;
+  event.type = NUX_MOUSE_RELEASED;
+  wnd_compositor.ProcessEvent(event);
+  ASSERT_EQ(0, tracker_window->child_mouse_events_received.size());
+  ASSERT_EQ(1, tracker_window->mouse_up_emission_count);
+  ASSERT_EQ(0, tracked_area->mouse_up_emission_count);
+
+  tracker_window->Dispose();
+}
+
 #endif // NUX_GESTURES_SUPPORT
 
 }
